BotAccessSettings class abstract

This object describes the access settings of a bot.

Available extensions
Annotations
  • @freezed

Constructors

BotAccessSettings({@JsonKey.new(name: 'is_access_restricted') required bool isAccessRestricted, @JsonKey.new(name: 'added_users') List<User>? addedUsers})
Creates a new BotAccessSettings object.
const
factory
BotAccessSettings.fromJson(Map<String, dynamic> json)
Creates a new BotAccessSettings object from a JSON Map.
factory

Properties

addedUsers List<User>?
Optional. The list of other users who have access to the bot if the access is restricted.
no setterinherited
copyWith → $BotAccessSettingsCopyWith<BotAccessSettings>
Create a copy of BotAccessSettings with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isAccessRestricted bool
True, if only selected users can access the bot. The bot's owner can always access it.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_BotAccessSettings value)) → TResult

Available on BotAccessSettings, provided by the BotAccessSettingsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_BotAccessSettings value)?) → TResult?

Available on BotAccessSettings, provided by the BotAccessSettingsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_BotAccessSettings value)?, {required TResult orElse()}) → TResult

Available on BotAccessSettings, provided by the BotAccessSettingsPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this BotAccessSettings to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited