BotAccessSettings constructor

const BotAccessSettings({
  1. @JsonKey.new(name: 'is_access_restricted') required bool isAccessRestricted,
  2. @JsonKey.new(name: 'added_users') List<User>? addedUsers,
})

Creates a new BotAccessSettings object.

Implementation

const factory BotAccessSettings({
  /// True, if only selected users can access the bot. The bot's owner can always access it.
  @JsonKey(name: 'is_access_restricted') required bool isAccessRestricted,

  /// Optional. The list of other users who have access to the bot if the access is restricted.
  @JsonKey(name: 'added_users') List<User>? addedUsers,
}) = _BotAccessSettings;