isAccessRestricted property
True, if only selected users can access the bot. The bot's owner can always access it.
Implementation
@JsonKey(name: 'is_access_restricted')
bool get isAccessRestricted;
True, if only selected users can access the bot. The bot's owner can always access it.
@JsonKey(name: 'is_access_restricted')
bool get isAccessRestricted;