ChatBoostRemoved class abstract

This object represents a boost removed from a chat.

Implemented types
Annotations
  • @freezed

Constructors

ChatBoostRemoved({@JsonKey.new(name: 'chat') required Chat chat, @JsonKey.new(name: 'boost_id') required String boostId, @JsonKey.new(name: 'remove_date') required int removeDate, required ChatBoostSource source})
Creates a ChatBoostRemoved object.
const
factory
ChatBoostRemoved.fromJson(Map<String, dynamic> json)
Creates a ChatBoostRemoved object from a JSON object.
factory

Properties

boostId → String
Unique identifier of the boost
no setterinherited
chat → Chat
Chat which was boosted
no setterinherited
copyWith → $ChatBoostRemovedCopyWith<ChatBoostRemoved>
Create a copy of ChatBoostRemoved with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
removeDate → int
Point in time (Unix timestamp) when the boost was removed
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ChatBoostSource
Source of the removed boost
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ChatBoostRemoved to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited