ChatBoostUpdated class abstract

This object represents a boost added to a chat or changed.

Implemented types
Annotations
  • @freezed

Constructors

ChatBoostUpdated({@JsonKey.new(name: 'chat') required Chat chat, @JsonKey.new(name: 'boost') required ChatBoost boost})
Creates a ChatBoostUpdated object.
const
factory
ChatBoostUpdated.fromJson(Map<String, dynamic> json)
Creates a ChatBoostUpdated object from a JSON object.
factory

Properties

boost → ChatBoost
Information about the chat boost
no setterinherited
chat → Chat
Chat which was boosted
no setterinherited
copyWith → $ChatBoostUpdatedCopyWith<ChatBoostUpdated>
Create a copy of ChatBoostUpdated with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ChatBoostUpdated to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited