firstProfileAudio property
Optional. For private chats, the first audio added to the profile of the user
Implementation
@JsonKey(name: 'first_profile_audio')
Audio? get firstProfileAudio;
Optional. For private chats, the first audio added to the profile of the user
@JsonKey(name: 'first_profile_audio')
Audio? get firstProfileAudio;