guardBot property
Optional. The bot that processes join request queries in the chat. The field is only available to chat administrators.
Implementation
@JsonKey(name: 'guard_bot')
User? get guardBot;
Optional. The bot that processes join request queries in the chat. The field is only available to chat administrators.
@JsonKey(name: 'guard_bot')
User? get guardBot;