ChatJoinRequest class abstract

Represents a join request sent to a chat.

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

ChatJoinRequest({@JsonKey.new(name: 'chat') required Chat chat, @JsonKey.new(name: 'from') required User from, @JsonKey.new(name: 'date') required int date, @JsonKey.new(name: 'bio') String? bio, @JsonKey.new(name: 'invite_link') ChatInviteLink? inviteLink, @JsonKey.new(name: 'user_chat_id') required int userChatId})
Creates a new ChatJoinRequest object.
const
factory
ChatJoinRequest.fromJson(Map<String, dynamic> json)
Creates a new ChatJoinRequest object from json.
factory

Properties

bio → String?
Optional. Bio of the user.
no setterinherited
chat → Chat
Chat to which the request was sent
no setterinherited
copyWith → $ChatJoinRequestCopyWith<ChatJoinRequest>
Create a copy of ChatJoinRequest with the given fields replaced by the non-null parameter values.
no setterinherited
date → int
Date the request was sent in Unix time
no setterinherited
dateTime → DateTime

Available on ChatJoinRequest, provided by the ChatJoinRequestExt extension

Returns a DateTime object representing the date field
no setter
from → User
User that sent the join request
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
Optional. Chat invite link that was used by the user to send the join request
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → User

Available on ChatJoinRequest, provided by the ChatJoinRequestExt extension

User that sent the join request (alias for from)
no setter
userChatId → int
Since Bot API 6.5
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ChatJoinRequest to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited