ChatOwnerChanged class abstract
Describes a service message about the chat owner leaving the chat.
Since: Bot API 9.4
- Available extensions
- Annotations
-
- @freezed
Constructors
- ChatOwnerChanged({@JsonKey.new(name: 'new_owner') required User newOwner})
-
Creates a ChatOwnerChanged instance
constfactory
-
ChatOwnerChanged.fromJson(Map<
String, dynamic> json) -
Creates a ChatOwnerChanged from a JSON map
factory
Properties
-
copyWith
→ $ChatOwnerChangedCopyWith<
ChatOwnerChanged> -
Create a copy of ChatOwnerChanged
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- newOwner → User
-
The new owner of the chat.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ChatOwnerChanged value)) → TResult -
Available on ChatOwnerChanged, provided by the ChatOwnerChangedPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ChatOwnerChanged value)?) → TResult? -
Available on ChatOwnerChanged, provided by the ChatOwnerChangedPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ChatOwnerChanged value)?, {required TResult orElse()}) → TResult -
Available on ChatOwnerChanged, provided by the ChatOwnerChangedPatterns extension
A variant ofmapthat fallback to returningorElse. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ChatOwnerChanged to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited