newOwner property

  1. @JsonKey.new(name: 'new_owner')
User? get newOwner
inherited

Optional. The user which will be the new owner of the chat if the previous owner does not return to the chat.

Implementation

@JsonKey(name: 'new_owner')
User? get newOwner;