canReactToMessages property
Optional. True, if the user is allowed to react to messages. If omitted, defaults to the value of can_send_messages.
Implementation
@JsonKey(name: 'can_react_to_messages')
bool? get canReactToMessages;
Optional. True, if the user is allowed to react to messages. If omitted, defaults to the value of can_send_messages.
@JsonKey(name: 'can_react_to_messages')
bool? get canReactToMessages;