Checklist class abstract

Describes a checklist.

Annotations
  • @freezed

Constructors

Checklist({@JsonKey.new(name: 'title') required String title, @JsonKey.new(name: 'title_entities') List<MessageEntity>? titleEntities, @JsonKey.new(name: 'tasks') required List<ChecklistTask> tasks, @JsonKey.new(name: 'others_can_add_tasks') bool? othersCanAddTasks, @JsonKey.new(name: 'others_can_mark_tasks_as_done') bool? othersCanMarkTasksAsDone})
Creates a new Checklist object.
const
factory
Checklist.fromJson(Map<String, dynamic> json)
Creates a new Checklist object from a JSON Map.
factory

Properties

copyWith → $ChecklistCopyWith<Checklist>
Create a copy of Checklist with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
othersCanAddTasks → bool?
Optional. True, if users other than the creator of the list can add tasks to the list
no setterinherited
othersCanMarkTasksAsDone → bool?
Optional. True, if users other than the creator of the list can mark tasks as done or not done
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tasks → List<ChecklistTask>
List of tasks in the checklist
no setterinherited
title → String
Title of the checklist
no setterinherited
titleEntities → List<MessageEntity>?
Optional. Special entities that appear in the checklist title
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Checklist to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited