ChecklistTask class abstract

Describes a task in a checklist.

Available extensions
Annotations
  • @freezed

Constructors

ChecklistTask({@JsonKey.new(name: 'id') required int id, @JsonKey.new(name: 'text') required String text, @JsonKey.new(name: 'text_entities') List<MessageEntity>? textEntities, @JsonKey.new(name: 'completed_by_user') User? completedByUser, @JsonKey.new(name: 'completion_date') int? completionDate})
Creates a new ChecklistTask object.
const
factory
ChecklistTask.fromJson(Map<String, dynamic> json)
Creates a new ChecklistTask object from a JSON Map.
factory

Properties

completedByUser → User?
Optional. User that completed the task; omitted if the task wasn't completed
no setterinherited
completionDate → int?
Optional. Point in time (Unix timestamp) when the task was completed; 0 if the task wasn't completed
no setterinherited
completionDateTime → DateTime?

Available on ChecklistTask, provided by the ChecklistTaskExt extension

Returns the completion date as a DateTime object if the task is completed
no setter
copyWith → $ChecklistTaskCopyWith<ChecklistTask>
Create a copy of ChecklistTask with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
Unique identifier of the task
no setterinherited
isCompleted → bool

Available on ChecklistTask, provided by the ChecklistTaskExt extension

Returns true if the task is completed
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Text of the task
no setterinherited
textEntities → List<MessageEntity>?
Optional. Special entities that appear in the task text
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ChecklistTask to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited