ChecklistTasksAdded class abstract

Describes a service message about tasks added to a checklist.

Annotations
  • @freezed

Constructors

ChecklistTasksAdded({@JsonKey.new(name: 'checklist_message') Message? checklistMessage, @JsonKey.new(name: 'tasks') required List<ChecklistTask> tasks})
Creates a new ChecklistTasksAdded object.
const
factory
ChecklistTasksAdded.fromJson(Map<String, dynamic> json)
Creates a new ChecklistTasksAdded object from a JSON Map.
factory

Properties

checklistMessage → Message?
Optional. Message containing the checklist to which the tasks were added. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
no setterinherited
copyWith → $ChecklistTasksAddedCopyWith<ChecklistTasksAdded>
Create a copy of ChecklistTasksAdded with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tasks → List<ChecklistTask>
List of tasks added to the checklist
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ChecklistTasksAdded to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited