ChecklistTasksDone class abstract

Describes a service message about checklist tasks marked as done or not done.

Annotations
  • @freezed

Constructors

ChecklistTasksDone({@JsonKey.new(name: 'checklist_message') Message? checklistMessage, @JsonKey.new(name: 'marked_as_done_task_ids') List<int>? markedAsDoneTaskIds, @JsonKey.new(name: 'marked_as_not_done_task_ids') List<int>? markedAsNotDoneTaskIds})
Creates a new ChecklistTasksDone object.
const
factory
ChecklistTasksDone.fromJson(Map<String, dynamic> json)
Creates a new ChecklistTasksDone object from a JSON Map.
factory

Properties

checklistMessage → Message?
Optional. Message containing the checklist whose tasks were marked as done or not done. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
no setterinherited
copyWith → $ChecklistTasksDoneCopyWith<ChecklistTasksDone>
Create a copy of ChecklistTasksDone with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
markedAsDoneTaskIds → List<int>?
Optional. Identifiers of the tasks that were marked as done
no setterinherited
markedAsNotDoneTaskIds → List<int>?
Optional. Identifiers of the tasks that were marked as not done
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ChecklistTasksDone to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited