CommunityChatAdded class abstract

Describes a service message about a chat being added to a community.

Available extensions
Annotations
  • @freezed

Constructors

CommunityChatAdded({@JsonKey.new(name: 'community') required Community community})
Creates a new CommunityChatAdded object.
const
factory
CommunityChatAdded.fromJson(Map<String, dynamic> json)
Creates a new CommunityChatAdded object from a JSON Map.
factory

Properties

community Community
The new community to which the chat belongs
no setterinherited
copyWith → $CommunityChatAddedCopyWith<CommunityChatAdded>
Create a copy of CommunityChatAdded with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CommunityChatAdded value)) → TResult

Available on CommunityChatAdded, provided by the CommunityChatAddedPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CommunityChatAdded value)?) → TResult?

Available on CommunityChatAdded, provided by the CommunityChatAddedPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CommunityChatAdded value)?, {required TResult orElse()}) → TResult

Available on CommunityChatAdded, provided by the CommunityChatAddedPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CommunityChatAdded to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited