receiverUserId property

  1. @JsonKey.new(name: 'receiver_user_id')
int get receiverUserId
inherited

Identifier of the user who will receive the message. It is not guaranteed that the user will receive the message, especially if they are offline.

Implementation

@JsonKey(name: 'receiver_user_id')
int get receiverUserId;