ForumTopicCreated class abstract

This object represents a service message about a new forum topic created in the chat.

Annotations
  • @freezed

Constructors

ForumTopicCreated({@JsonKey.new(name: 'name') required String name, @JsonKey.new(name: 'icon_color') required int iconColor, @JsonKey.new(name: 'icon_custom_emoji_id') String? iconCustomEmojiId})
Creates a new ForumTopicCreated object.
const
factory
ForumTopicCreated.fromJson(Map<String, dynamic> json)
Creates a new ForumTopicCreated object from json.
factory

Properties

copyWith → $ForumTopicCreatedCopyWith<ForumTopicCreated>
Create a copy of ForumTopicCreated with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
iconColor → int
Color of the topic icon in RGB format
no setterinherited
iconCustomEmojiId → String?
Optional. Unique identifier of the custom emoji shown as the topic icon
no setterinherited
name → String
Name of the topic
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ForumTopicCreated to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited