ForumTopicEdited class abstract

This object represents a service message about an edited forum topic.

Annotations
  • @freezed

Constructors

ForumTopicEdited({@JsonKey.new(name: 'name') String? name, @JsonKey.new(name: 'icon_custom_emoji_id') String? iconCustomEmojiId})
Creates a new ForumTopicEdited object.
const
factory
ForumTopicEdited.fromJson(Map<String, dynamic> json)
Creates a new ForumTopicEdited object from json.
factory

Properties

copyWith → $ForumTopicEditedCopyWith<ForumTopicEdited>
Create a copy of ForumTopicEdited with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
iconCustomEmojiId → String?
Optional. New identifier of the custom emoji shown as the topic icon, if it was edited; an empty string if the icon was removed
no setterinherited
name → String?
Optional. New name of the topic, if it was edited
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ForumTopicEdited to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited