InaccessibleMessage class abstract

This object describes a message that was deleted or is otherwise inaccessible to the bot.

Implemented types
Annotations
  • @Freezed.new(copyWith: false)

Constructors

InaccessibleMessage({required Chat chat, @JsonKey.new(name: 'message_id') required int messageId, @Default.new(0) int date})
Creates InaccessibleMessage instance
const
factory
InaccessibleMessage.fromJson(Map<String, dynamic> json)
Constructor from JSON data
factory

Properties

chat → Chat
Chat to which the message belongs
no setterinherited
date → int
Date the message was sent in Unix time
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
messageId → int
Unique message identifier
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Converts the object into JSON map
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited