disabled property
Optional. If set, then the button is disabled and does nothing
Since: Bot API 10.3
Implementation
@JsonKey(name: 'disabled')
DisabledButton? get disabled;
Optional. If set, then the button is disabled and does nothing
Since: Bot API 10.3
@JsonKey(name: 'disabled')
DisabledButton? get disabled;