InlineQuery class abstract

This object represents an incoming inline query. When the user sends an empty query, your bot could return some default or trending results.

Implemented types
Annotations
  • @freezed

Constructors

InlineQuery({@JsonKey.new(name: 'id') required String id, @JsonKey.new(name: 'from') required User from, @JsonKey.new(name: 'query') required String query, @JsonKey.new(name: 'offset') required String offset, @JsonKey.new(name: 'chat_type') ChatType? chatType, Location? location})
Creates an incoming inline query
const
factory
InlineQuery.fromJson(Map<String, dynamic> json)
Creates an InlineQuery from a JSON map
factory

Properties

chatType → ChatType?
Optional. Type of the chat from which the inline query was sent. Can be either "sender" for a private chat with the inline query sender, "private", "group", "supergroup", or "channel". The chat type should be always known for requests sent from official clients and most third-party clients, unless the request was sent from a secret chat
no setterinherited
copyWith → $InlineQueryCopyWith<InlineQuery>
Create a copy of InlineQuery with the given fields replaced by the non-null parameter values.
no setterinherited
from → User
Sender
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier for this query
no setterinherited
location → Location?
Optional. Sender location, only for bots that request user location
no setterinherited
offset → String
Offset of the results to be returned, can be controlled by the bot
no setterinherited
query → String
Text of the query (up to 256 characters)
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this InlineQuery to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited