InlineQueryResultGame class abstract

Represents a Game.

Implemented types
Annotations
  • @freezed

Constructors

InlineQueryResultGame({@JsonKey.new(name: 'type') @Default.new(InlineQueryResultType.game) InlineQueryResultType type, @JsonKey.new(name: 'id') required String id, @JsonKey.new(name: 'game_short_name') required String gameShortName, @JsonKey.new(name: 'reply_markup') InlineKeyboardMarkup? replyMarkup})
Constructs an InlineQueryResultGame object
const
factory
InlineQueryResultGame.fromJson(Map<String, dynamic> json)
Constructs an InlineQueryResultGame object from a JSON map
factory

Properties

copyWith → $InlineQueryResultGameCopyWith<InlineQueryResultGame>
Create a copy of InlineQueryResultGame with the given fields replaced by the non-null parameter values.
no setterinherited
gameShortName → String
Short name of the game
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier for this result, 1-64 Bytes
no setterinherited
replyMarkup → InlineKeyboardMarkup?
Optional. Inline keyboard attached to the message
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → InlineQueryResultType
Type of the result, always InlineQueryResultType.game
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this InlineQueryResultGame to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited