InputChecklistTask class abstract

Describes a task to add to a checklist.

Annotations
  • @freezed

Constructors

InputChecklistTask({@JsonKey.new(name: 'id') required int id, @JsonKey.new(name: 'text') required String text, @JsonKey.new(name: 'parse_mode') ParseMode? parseMode, @JsonKey.new(name: 'text_entities') List<MessageEntity>? textEntities})
Creates a new InputChecklistTask object.
const
factory
InputChecklistTask.fromJson(Map<String, dynamic> json)
Creates a new InputChecklistTask object from a JSON Map.
factory

Properties

copyWith → $InputChecklistTaskCopyWith<InputChecklistTask>
Create a copy of InputChecklistTask with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
Unique identifier of the task; must be positive and unique among all task identifiers currently present in the checklist
no setterinherited
parseMode → ParseMode?
Optional. Mode for parsing entities in the text. See formatting options for more details.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Text of the task; 1-100 characters after entities parsing
no setterinherited
textEntities → List<MessageEntity>?
Optional. List of special entities that appear in the text, which can be specified instead of parse_mode. Currently, only bold, italic, underline, strikethrough, spoiler, and custom_emoji entities are allowed.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this InputChecklistTask to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited