hasSpoiler property
Optional. Pass True if the live photo needs to be covered with a spoiler animation
Implementation
@JsonKey(name: 'has_spoiler')
bool? get hasSpoiler;
Optional. Pass True if the live photo needs to be covered with a spoiler animation
@JsonKey(name: 'has_spoiler')
bool? get hasSpoiler;