InputMediaLocation class abstract

Represents a location to be sent.

Implemented types
Available extensions
Annotations
  • @Freezed.new(fromJson: false, toJson: true)

Constructors

InputMediaLocation({@JsonKey.new(name: 'type') @Default.new(InputMediaType.location) InputMediaType type, @JsonKey.new(name: 'latitude') required double latitude, @JsonKey.new(name: 'longitude') required double longitude, @JsonKey.new(name: 'horizontal_accuracy') double? horizontalAccuracy})
Creates a new InputMediaLocation object.
const
factory

Properties

copyWith → $InputMediaLocationCopyWith<InputMediaLocation>
Create a copy of InputMediaLocation with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
horizontalAccuracy double?
Optional. The radius of uncertainty for the location, measured in meters; 0-1500
no setterinherited
latitude double
Latitude of the location
no setterinherited
longitude double
Longitude of the location
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type InputMediaType
Type of the media, must be location
no setterinherited

Methods

getInputFiles() Iterable<InputFile?>
Returns an iterable of files
map<TResult extends Object?>(TResult $default(_InputMediaLocation value)) → TResult

Available on InputMediaLocation, provided by the InputMediaLocationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_InputMediaLocation value)?) → TResult?

Available on InputMediaLocation, provided by the InputMediaLocationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_InputMediaLocation value)?, {required TResult orElse()}) → TResult

Available on InputMediaLocation, provided by the InputMediaLocationPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this InputMediaLocation to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited