InputMediaLocationPatterns extension

Adds pattern-matching-related methods to InputMediaLocation.

on

Methods

map<TResult extends Object?>(TResult $default(_InputMediaLocation value)) → TResult

Available on InputMediaLocation, provided by the InputMediaLocationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_InputMediaLocation value)?) → TResult?

Available on InputMediaLocation, provided by the InputMediaLocationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_InputMediaLocation value)?, {required TResult orElse()}) → TResult

Available on InputMediaLocation, provided by the InputMediaLocationPatterns extension

A variant of map that fallback to returning orElse.