InputMediaSticker class abstract

Represents a sticker file to be sent.

Implemented types
Available extensions
Annotations
  • @Freezed.new(fromJson: false, toJson: true)

Constructors

InputMediaSticker({@JsonKey.new(name: 'type') @Default.new(InputMediaType.sticker) InputMediaType type, @JsonKey.new(name: 'media') @InputFileConverter() required InputFile media, @JsonKey.new(name: 'emoji') String? emoji})
Creates a new InputMediaSticker object.
const
factory

Properties

copyWith → $InputMediaStickerCopyWith<InputMediaSticker>
Create a copy of InputMediaSticker with the given fields replaced by the non-null parameter values.
no setterinherited
emoji String?
Optional. Emoji associated with the sticker; only for just uploaded stickers.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
media InputFile
File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a .WEBP sticker from the Internet, or pass “attach://<file_attach_name>” to upload a new .WEBP, .TGS, or .WEBM sticker using multipart/form-data under <file_attach_name> name.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type InputMediaType
Type of the media, must be sticker
no setterinherited

Methods

getInputFiles() Iterable<InputFile?>
Returns an iterable of files
map<TResult extends Object?>(TResult $default(_InputMediaSticker value)) → TResult

Available on InputMediaSticker, provided by the InputMediaStickerPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_InputMediaSticker value)?) → TResult?

Available on InputMediaSticker, provided by the InputMediaStickerPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_InputMediaSticker value)?, {required TResult orElse()}) → TResult

Available on InputMediaSticker, provided by the InputMediaStickerPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this InputMediaSticker to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited