InputPollOptionMediaConverter class
Custom converter for InputPollOptionMedia serialization.
Constructors
- InputPollOptionMediaConverter()
-
Creates a new instance of the converter.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromJson(
Map< String, dynamic> json) → InputPollOptionMedia -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
InputPollOptionMedia data) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited