InputRichBlockListItem constructor

const InputRichBlockListItem({
  1. @JsonKey.new(name: 'blocks') required List<InputRichBlock> blocks,
  2. @JsonKey.new(name: 'has_checkbox') bool? hasCheckbox,
  3. @JsonKey.new(name: 'is_checked') bool? isChecked,
  4. @JsonKey.new(name: 'value') int? value,
  5. @JsonKey.new(name: 'type') String? type,
})

Creates a new InputRichBlockListItem object.

Implementation

const factory InputRichBlockListItem({
  /// The content of the item
  @JsonKey(name: 'blocks') required List<InputRichBlock> blocks,

  /// Optional. Pass True if the item has a checkbox
  @JsonKey(name: 'has_checkbox') bool? hasCheckbox,

  /// Optional. Pass True if the item has a checked checkbox
  @JsonKey(name: 'is_checked') bool? isChecked,

  /// Optional. For ordered lists, the numeric value of the item label
  @JsonKey(name: 'value') int? value,

  /// Optional. For ordered lists, the type of the item label; must be one of
  /// “a” for lowercase letters, “A” for uppercase letters, “i” for lowercase
  /// Roman numerals, “I” for uppercase Roman numerals, or “1” for decimal
  /// numbers
  @JsonKey(name: 'type') String? type,
}) = _InputRichBlockListItem;