blocks property
Optional. Content of the rich message to send described as a list of blocks
Implementation
@JsonKey(name: 'blocks')
List<InputRichBlock>? get blocks;
Optional. Content of the rich message to send described as a list of blocks
@JsonKey(name: 'blocks')
List<InputRichBlock>? get blocks;