html property
Optional. Content of the rich message to send described using HTML formatting. See rich message formatting options for more details.
Implementation
@JsonKey(name: 'html')
String? get html;
Optional. Content of the rich message to send described using HTML formatting. See rich message formatting options for more details.
@JsonKey(name: 'html')
String? get html;