isRtl property
Optional. Pass True if the rich message must be shown right-to-left
Implementation
@JsonKey(name: 'is_rtl')
bool? get isRtl;
Optional. Pass True if the rich message must be shown right-to-left
@JsonKey(name: 'is_rtl')
bool? get isRtl;