markdown property
Optional. Content of the rich message to send described using Markdown formatting. See rich message formatting options for more details.
Implementation
@JsonKey(name: 'markdown')
String? get markdown;
Optional. Content of the rich message to send described using Markdown formatting. See rich message formatting options for more details.
@JsonKey(name: 'markdown')
String? get markdown;