media property
Optional. List of media that are specified in the markdown or html fields using tg://photo?id=, tg://video?id=, and tg://audio?id= links
Implementation
@JsonKey(name: 'media')
List<InputRichMessageMedia>? get media;
Optional. List of media that are specified in the markdown or html fields using tg://photo?id=, tg://video?id=, and tg://audio?id= links
@JsonKey(name: 'media')
List<InputRichMessageMedia>? get media;