skipEntityDetection property

  1. @JsonKey.new(name: 'skip_entity_detection')
bool? get skipEntityDetection
inherited

Optional. Pass True to skip automatic detection of entities (e.g., URLs, email addresses, username mentions, hashtags, cashtags, bot commands, or phone numbers) in the text

Implementation

@JsonKey(name: 'skip_entity_detection')
bool? get skipEntityDetection;