media property
The media to be sent. Everything except the media itself and its properties is ignored.
Implementation
@JsonKey(name: 'media')
InputMedia get media;
The media to be sent. Everything except the media itself and its properties is ignored.
@JsonKey(name: 'media')
InputMedia get media;