iconCustomEmojiId property
Optional. Unique identifier of the custom emoji shown before the text of the button. Can only be used by bots that purchased additional usernames on Fragment or in the messages directly sent by the bot to private, group and supergroup chats if the owner of the bot has a Telegram Premium subscription.
Since: Bot API 9.4
Implementation
@JsonKey(name: 'icon_custom_emoji_id')
String? get iconCustomEmojiId;