requestManagedBot property

  1. @JsonKey.new(name: 'request_managed_bot')
KeyboardButtonRequestManagedBot? get requestManagedBot
inherited

Optional. If specified, pressing the button will prompt the user to create a managed bot. Information about the created bot will be shared with the bot using the update managed_bot and a Message with the field managed_bot_created. Available in private chats only.

Since: Bot API 9.6

Implementation

@JsonKey(name: 'request_managed_bot')
KeyboardButtonRequestManagedBot? get requestManagedBot;