LivePhoto class abstract

This object represents a live photo.

Available extensions
Annotations
  • @freezed

Constructors

LivePhoto({@JsonKey.new(name: 'photo') List<PhotoSize>? photo, @JsonKey.new(name: 'file_id') required String fileId, @JsonKey.new(name: 'file_unique_id') required String fileUniqueId, @JsonKey.new(name: 'width') required int width, @JsonKey.new(name: 'height') required int height, @JsonKey.new(name: 'duration') required int duration, @JsonKey.new(name: 'mime_type') String? mimeType, @JsonKey.new(name: 'file_size') int? fileSize})
Creates a new LivePhoto object.
const
factory
LivePhoto.fromJson(Map<String, dynamic> json)
Creates a new LivePhoto object from a JSON Map.
factory

Properties

copyWith → $LivePhotoCopyWith<LivePhoto>
Create a copy of LivePhoto with the given fields replaced by the non-null parameter values.
no setterinherited
duration int
Duration of the video in seconds as defined by the sender
no setterinherited
durationTime Duration

Available on LivePhoto, provided by the LivePhotoExt extension

Duration of the video as Duration object.
no setter
fileId String
Identifier for the video file which can be used to download or reuse the file
no setterinherited
fileSize int?
Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.
no setterinherited
fileUniqueId String
Unique identifier for the video file which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
height int
Video height as defined by the sender
no setterinherited
mimeType String?
Optional. MIME type of the file as defined by the sender
no setterinherited
photo List<PhotoSize>?
Optional. Available sizes of the corresponding static photo
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Video width as defined by the sender
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_LivePhoto value)) → TResult

Available on LivePhoto, provided by the LivePhotoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LivePhoto value)?) → TResult?

Available on LivePhoto, provided by the LivePhotoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LivePhoto value)?, {required TResult orElse()}) → TResult

Available on LivePhoto, provided by the LivePhotoPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this LivePhoto to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited