fileId property
Identifier for the video file which can be used to download or reuse the file
Implementation
@JsonKey(name: 'file_id')
String get fileId;
Identifier for the video file which can be used to download or reuse the file
@JsonKey(name: 'file_id')
String get fileId;