fileUniqueId property

  1. @JsonKey.new(name: 'file_unique_id')
String get fileUniqueId
inherited

Unique identifier for the video file which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.

Implementation

@JsonKey(name: 'file_unique_id')
String get fileUniqueId;