ManagedBotCreated class abstract

This object contains information about the bot that was created to be managed by the current bot.

Available extensions
Annotations
  • @freezed

Constructors

ManagedBotCreated({@JsonKey.new(name: 'bot') required User bot})
Creates a new ManagedBotCreated object.
const
factory
ManagedBotCreated.fromJson(Map<String, dynamic> json)
Creates a new ManagedBotCreated from a JSON object.
factory

Properties

bot User
Information about the bot. The bot's token can be fetched using the method getManagedBotToken.
no setterinherited
copyWith → $ManagedBotCreatedCopyWith<ManagedBotCreated>
Create a copy of ManagedBotCreated with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ManagedBotCreated value)) → TResult

Available on ManagedBotCreated, provided by the ManagedBotCreatedPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ManagedBotCreated value)?) → TResult?

Available on ManagedBotCreated, provided by the ManagedBotCreatedPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ManagedBotCreated value)?, {required TResult orElse()}) → TResult

Available on ManagedBotCreated, provided by the ManagedBotCreatedPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ManagedBotCreated to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited