ManagedBotUpdated class abstract

This object contains information about the creation or token update of a bot that is managed by the current bot.

Available extensions
Annotations
  • @freezed

Constructors

ManagedBotUpdated({@JsonKey.new(name: 'user') required User user, @JsonKey.new(name: 'bot') required User bot})
Creates a new ManagedBotUpdated instance
const
factory
ManagedBotUpdated.fromJson(Map<String, dynamic> json)
Creates a new ManagedBotUpdated from JSON object.
factory

Properties

bot User
Information about the bot. Token of the bot can be fetched using the method getManagedBotToken.
no setterinherited
copyWith → $ManagedBotUpdatedCopyWith<ManagedBotUpdated>
Create a copy of ManagedBotUpdated with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user User
User that created the bot
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ManagedBotUpdated value)) → TResult

Available on ManagedBotUpdated, provided by the ManagedBotUpdatedPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ManagedBotUpdated value)?) → TResult?

Available on ManagedBotUpdated, provided by the ManagedBotUpdatedPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ManagedBotUpdated value)?, {required TResult orElse()}) → TResult

Available on ManagedBotUpdated, provided by the ManagedBotUpdatedPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ManagedBotUpdated to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited