bot property
Information about the bot. Token of the bot can be fetched using the method getManagedBotToken.
Implementation
@JsonKey(name: 'bot')
User get bot;
Information about the bot. Token of the bot can be fetched using the method getManagedBotToken.
@JsonKey(name: 'bot')
User get bot;