communityChatJoined property
Optional. Service message: chat was joined by a user from a Community
Implementation
@JsonKey(name: 'community_chat_joined')
CommunityChatJoined? get communityChatJoined;
Optional. Service message: chat was joined by a user from a Community
@JsonKey(name: 'community_chat_joined')
CommunityChatJoined? get communityChatJoined;