guestBotCallerChat property

  1. @JsonKey.new(name: 'guest_bot_caller_chat')
Chat? get guestBotCallerChat
inherited

Optional. For a message sent by a guest bot, this is the chat whose original message triggered the bot's response

Implementation

@JsonKey(name: 'guest_bot_caller_chat')
Chat? get guestBotCallerChat;