guestBotCallerUser property

  1. @JsonKey.new(name: 'guest_bot_caller_user')
User? get guestBotCallerUser
inherited

Optional. For a message sent by a guest bot, this is the user whose original message triggered the bot's response

Implementation

@JsonKey(name: 'guest_bot_caller_user')
User? get guestBotCallerUser;