livePhoto property

  1. @JsonKey.new(name: 'live_photo')
LivePhoto? get livePhoto
inherited

Optional. Message is a live photo, information about the live photo. For backward compatibility, when this field is set, the photo field will also be set.

Implementation

@JsonKey(name: 'live_photo')
LivePhoto? get livePhoto;