managedBotCreated property
Optional. Service message: user created a bot that will be managed by the current bot
Implementation
@JsonKey(name: 'managed_bot_created')
ManagedBotCreated? get managedBotCreated;
Optional. Service message: user created a bot that will be managed by the current bot
@JsonKey(name: 'managed_bot_created')
ManagedBotCreated? get managedBotCreated;