receiverUser property
Optional. For ephemeral messages, the user who received the message
Implementation
@JsonKey(name: 'receiver_user')
User? get receiverUser;
Optional. For ephemeral messages, the user who received the message
@JsonKey(name: 'receiver_user')
User? get receiverUser;