senderTag property
Optional. Tag or custom title of the sender of the message; for supergroups only
Implementation
@JsonKey(name: 'sender_tag')
String? get senderTag;
Optional. Tag or custom title of the sender of the message; for supergroups only
@JsonKey(name: 'sender_tag')
String? get senderTag;