MessageAutoDeleteTimerChanged class abstract

This object represents a service message about a change in auto-delete timer settings.

Available extensions
Annotations
  • @freezed

Constructors

MessageAutoDeleteTimerChanged({@JsonKey.new(name: 'message_auto_delete_time') required int messageAutoDeleteTime})
Creates a service message about auto-delete timer change
const
factory
MessageAutoDeleteTimerChanged.fromJson(Map<String, dynamic> json)
Creates a MessageAutoDeleteTimerChanged from a JSON map
factory

Properties

copyWith → $MessageAutoDeleteTimerChangedCopyWith<MessageAutoDeleteTimerChanged>
Create a copy of MessageAutoDeleteTimerChanged with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
messageAutoDeleteTime → int
New auto-delete time for messages in the chat; in seconds
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeInDuration → Duration

Available on MessageAutoDeleteTimerChanged, provided by the MessageAutoDeleteTimerChangedDurationExt extension

Returns the time in Duration object
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this MessageAutoDeleteTimerChanged to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited