OrderInfo class abstract

This object represents information about an order.

Annotations
  • @freezed

Constructors

OrderInfo({String? name, @JsonKey.new(name: 'phone_number') String? phoneNumber, @JsonKey.new(name: 'email') String? email, @JsonKey.new(name: 'shipping_address') ShippingAddress? shippingAddress})
Creates a new OrderInfo object.
const
factory
OrderInfo.fromJson(Map<String, dynamic> json)
Creates a OrderInfo object from a JSON object
factory

Properties

copyWith → $OrderInfoCopyWith<OrderInfo>
Create a copy of OrderInfo with the given fields replaced by the non-null parameter values.
no setterinherited
email → String?
User email
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String?
User name
no setterinherited
phoneNumber → String?
User's phone number
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress → ShippingAddress?
User shipping address
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this OrderInfo to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited