PaidMediaInfo class abstract

Describes the paid media added to a message.

Available extensions
Annotations
  • @freezed

Constructors

PaidMediaInfo({@JsonKey.new(name: 'star_count') required int starCount, @JsonKey.new(name: 'paid_media') required List<PaidMedia> paidMedia})
Constructs a PaidMediaInfo object.
const
factory
PaidMediaInfo.fromJson(Map<String, dynamic> json)
Creates a PaidMediaInfo object from JSON.
factory

Properties

copyWith → $PaidMediaInfoCopyWith<PaidMediaInfo>
Create a copy of PaidMediaInfo with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
paidMedia → List<PaidMedia>
Information about the paid media.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
starCount → int
The number of Telegram Stars that must be paid to buy access to the media.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PaidMediaInfo value)) → TResult

Available on PaidMediaInfo, provided by the PaidMediaInfoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PaidMediaInfo value)?) → TResult?

Available on PaidMediaInfo, provided by the PaidMediaInfoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PaidMediaInfo value)?, {required TResult orElse()}) → TResult

Available on PaidMediaInfo, provided by the PaidMediaInfoPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this PaidMediaInfo to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited