membersOnly property

  1. @JsonKey.new(name: 'members_only')
bool? get membersOnly
inherited

Optional. True if voting is limited to users who have been members of the chat where the poll was originally sent for more than 24 hours

Implementation

@JsonKey(name: 'members_only')
bool? get membersOnly;