audio property
Optional. Media is an audio file, information about the file; currently, can't be received in a poll option
Implementation
@JsonKey(name: 'audio')
Audio? get audio;
Optional. Media is an audio file, information about the file; currently, can't be received in a poll option
@JsonKey(name: 'audio')
Audio? get audio;