PreparedKeyboardButton class abstract

Describes a keyboard button to be used by a user of a Mini App.

Available extensions
Annotations
  • @freezed

Constructors

PreparedKeyboardButton({@JsonKey.new(name: 'id') required String id})
Creates a PreparedKeyboardButton object.
const
factory
PreparedKeyboardButton.fromJson(Map<String, dynamic> json)
Creates a PreparedKeyboardButton object from a JSON map.
factory

Properties

copyWith → $PreparedKeyboardButtonCopyWith<PreparedKeyboardButton>
Create a copy of PreparedKeyboardButton with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier of the keyboard button
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PreparedKeyboardButton value)) → TResult

Available on PreparedKeyboardButton, provided by the PreparedKeyboardButtonPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PreparedKeyboardButton value)?) → TResult?

Available on PreparedKeyboardButton, provided by the PreparedKeyboardButtonPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PreparedKeyboardButton value)?, {required TResult orElse()}) → TResult

Available on PreparedKeyboardButton, provided by the PreparedKeyboardButtonPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PreparedKeyboardButton to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited