ProximityAlertTriggered class abstract

This object represents the content of a service message, sent whenever a user in the chat triggers a proximity alert set by another user.

Annotations
  • @freezed

Constructors

ProximityAlertTriggered({@JsonKey.new(name: 'traveler') required User traveler, @JsonKey.new(name: 'watcher') required User watcher, @JsonKey.new(name: 'distance') required int distance})
Constructs a ProximityAlertTriggered object
const
factory
ProximityAlertTriggered.fromJson(Map<String, dynamic> json)
Creates a ProximityAlertTriggered object from JSON object
factory

Properties

copyWith → $ProximityAlertTriggeredCopyWith<ProximityAlertTriggered>
Create a copy of ProximityAlertTriggered with the given fields replaced by the non-null parameter values.
no setterinherited
distance → int
The distance between the users
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traveler → User
User that triggered the alert
no setterinherited
watcher → User
User that set the alert
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ProximityAlertTriggered to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited