ReplyParameters class abstract

Describes reply parameters for the message that is being sent.

Available extensions
Annotations
  • @freezed

Constructors

ReplyParameters({@JsonKey.new(name: 'message_id') int? messageId, @IDConverter() @JsonKey.new(name: 'chat_id') ID? chatId, @JsonKey.new(name: 'ephemeral_message_id') int? ephemeralMessageId, @JsonKey.new(name: 'allow_sending_without_reply') bool? allowSendingWithoutReply, @JsonKey.new(name: 'quote') String? quote, @JsonKey.new(name: 'quote_parse_mode') String? quoteParseMode, @JsonKey.new(name: 'quote_entities') List<MessageEntity>? quoteEntities, @JsonKey.new(name: 'quote_position') int? quotePosition, @JsonKey.new(name: 'checklist_task_id') int? checklistTaskId, @JsonKey.new(name: 'poll_option_id') String? pollOptionId})
Constructs a ReplyParameters.
const
factory
ReplyParameters.fromJson(Map<String, dynamic> json)
Creates a ReplyParameters object from a JSON object.
factory

Properties

allowSendingWithoutReply bool?
Pass True if the message should be sent even if the specified message to be replied to is not found. Always False for replies in another chat or forum topic, and sent ephemeral messages. Always True for messages sent on behalf of a business account.
no setterinherited
chatId ID?
If the message to be replied to is from a different chat, unique identifier for the chat or username of the bot, supergroup or channel in the format @username. Not supported for messages sent on behalf of a business account, messages from channel direct messages chats and ephemeral messages.
no setterinherited
checklistTaskId int?
Identifier of the specific checklist task to be replied to.
no setterinherited
copyWith → $ReplyParametersCopyWith<ReplyParameters>
Create a copy of ReplyParameters with the given fields replaced by the non-null parameter values.
no setterinherited
ephemeralMessageId int?
Identifier of the incoming ephemeral message that will be replied to in the current chat. A reply to an ephemeral message must itself be an ephemeral message. An ephemeral message may only be replied to within 15 seconds of being sent. Required if message_id isn't specified.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
messageId int?
Identifier of the message that will be replied to in the current chat, or in the chat chat_id if it is specified. Required if ephemeral_message_id isn't specified.
no setterinherited
pollOptionId String?
Persistent identifier of the specific poll option to be replied to.
no setterinherited
quote String?
Quoted part of the message to be replied to; 0-1024 characters after entities parsing. The quote must be an exact substring of the message to be replied to, including bold, italic, underline, strikethrough, spoiler, custom_emoji, and date_time entities. The message will fail to send if the quote isn't found in the original message. Ignored for ephemeral messages.
no setterinherited
quoteEntities List<MessageEntity>?
A JSON-serialized list of special entities that appear in the quote. It can be specified instead of quote_parse_mode.
no setterinherited
quoteParseMode String?
Mode for parsing entities in the quote. See formatting options for more details.
no setterinherited
quotePosition int?
Position of the quote in the original message in UTF-16 code units.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReplyParameters value)) → TResult

Available on ReplyParameters, provided by the ReplyParametersPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReplyParameters value)?) → TResult?

Available on ReplyParameters, provided by the ReplyParametersPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReplyParameters value)?, {required TResult orElse()}) → TResult

Available on ReplyParameters, provided by the ReplyParametersPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReplyParameters to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited