ReplyParameters constructor

const ReplyParameters({
  1. @JsonKey.new(name: 'message_id') int? messageId,
  2. @IDConverter() @JsonKey.new(name: 'chat_id') ID? chatId,
  3. @JsonKey.new(name: 'ephemeral_message_id') int? ephemeralMessageId,
  4. @JsonKey.new(name: 'allow_sending_without_reply') bool? allowSendingWithoutReply,
  5. @JsonKey.new(name: 'quote') String? quote,
  6. @JsonKey.new(name: 'quote_parse_mode') String? quoteParseMode,
  7. @JsonKey.new(name: 'quote_entities') List<MessageEntity>? quoteEntities,
  8. @JsonKey.new(name: 'quote_position') int? quotePosition,
  9. @JsonKey.new(name: 'checklist_task_id') int? checklistTaskId,
  10. @JsonKey.new(name: 'poll_option_id') String? pollOptionId,
})

Constructs a ReplyParameters.

Implementation

const factory ReplyParameters({
  /// Identifier of the message that will be replied to in the current chat,
  /// or in the chat chat_id if it is specified. Required if
  /// ephemeral_message_id isn't specified.
  @JsonKey(name: 'message_id') int? messageId,

  /// If the message to be replied to is from a different chat, unique
  /// identifier for the chat or username of the bot, supergroup or channel
  /// in the format @username. Not supported for messages sent on behalf of a
  /// business account, messages from channel direct messages chats and
  /// ephemeral messages.
  @IDConverter() @JsonKey(name: 'chat_id') ID? chatId,

  /// Identifier of the incoming ephemeral message that will be replied to in
  /// the current chat. A reply to an ephemeral message must itself be an
  /// ephemeral message. An ephemeral message may only be replied to within
  /// 15 seconds of being sent. Required if message_id isn't specified.
  @JsonKey(name: 'ephemeral_message_id') int? ephemeralMessageId,

  /// Pass True if the message should be sent even if the specified message to
  /// be replied to is not found. Always False for replies in another chat or
  /// forum topic, and sent ephemeral messages. Always True for messages sent
  /// on behalf of a business account.
  @JsonKey(name: 'allow_sending_without_reply')
  bool? allowSendingWithoutReply,

  /// Quoted part of the message to be replied to; 0-1024 characters after
  /// entities parsing. The quote must be an exact substring of the message to
  /// be replied to, including bold, italic, underline, strikethrough,
  /// spoiler, custom_emoji, and date_time entities. The message will fail to
  /// send if the quote isn't found in the original message. Ignored for
  /// ephemeral messages.
  @JsonKey(name: 'quote') String? quote,

  /// Mode for parsing entities in the quote. See formatting options for more
  /// details.
  @JsonKey(name: 'quote_parse_mode') String? quoteParseMode,

  /// A JSON-serialized list of special entities that appear in the quote. It
  /// can be specified instead of quote_parse_mode.
  @JsonKey(name: 'quote_entities') List<MessageEntity>? quoteEntities,

  /// Position of the quote in the original message in UTF-16 code units.
  @JsonKey(name: 'quote_position') int? quotePosition,

  /// Identifier of the specific checklist task to be replied to.
  @JsonKey(name: 'checklist_task_id') int? checklistTaskId,

  /// Persistent identifier of the specific poll option to be replied to.
  @JsonKey(name: 'poll_option_id') String? pollOptionId,
}) = _ReplyParameters;