chatId property

  1. @IDConverter()
  2. @JsonKey.new(name: 'chat_id')
ID? get chatId
inherited

If the message to be replied to is from a different chat, unique identifier for the chat or username of the bot, supergroup or channel in the format @username. Not supported for messages sent on behalf of a business account, messages from channel direct messages chats and ephemeral messages.

Implementation

@IDConverter()
@JsonKey(name: 'chat_id')
ID? get chatId;