pollOptionId property
Persistent identifier of the specific poll option to be replied to.
Implementation
@JsonKey(name: 'poll_option_id')
String? get pollOptionId;
Persistent identifier of the specific poll option to be replied to.
@JsonKey(name: 'poll_option_id')
String? get pollOptionId;