RichBlockCaption class abstract

Caption of a rich formatted block.

Available extensions
Annotations
  • @freezed

Constructors

RichBlockCaption({@JsonKey.new(name: 'text') @RichTextConverter() required RichText text, @JsonKey.new(name: 'credit') @RichTextConverter() RichText? credit})
Caption of a rich formatted block.
const
factory
RichBlockCaption.fromJson(Map<String, dynamic> json)
Creates a RichBlockCaption object from JSON.
factory

Properties

copyWith → $RichBlockCaptionCopyWith<RichBlockCaption>
Create a copy of RichBlockCaption with the given fields replaced by the non-null parameter values.
no setterinherited
credit RichText?
Optional. Block credit which corresponds to the HTML tag
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text RichText
Block caption
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_RichBlockCaption value)) → TResult

Available on RichBlockCaption, provided by the RichBlockCaptionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_RichBlockCaption value)?) → TResult?

Available on RichBlockCaption, provided by the RichBlockCaptionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_RichBlockCaption value)?, {required TResult orElse()}) → TResult

Available on RichBlockCaption, provided by the RichBlockCaptionPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this RichBlockCaption to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited