RichBlockListItem class abstract

An item of a list.

Available extensions
Annotations
  • @freezed

Constructors

RichBlockListItem({@JsonKey.new(name: 'label') required String label, @JsonKey.new(name: 'blocks') required List<RichBlock> blocks, @JsonKey.new(name: 'has_checkbox') bool? hasCheckbox, @JsonKey.new(name: 'is_checked') bool? isChecked, @JsonKey.new(name: 'value') int? value, @JsonKey.new(name: 'type') String? type})
An item of a list.
const
factory
RichBlockListItem.fromJson(Map<String, dynamic> json)
Creates a RichBlockListItem object from JSON.
factory

Properties

blocks → List<RichBlock>
The content of the item
no setterinherited
copyWith → $RichBlockListItemCopyWith<RichBlockListItem>
Create a copy of RichBlockListItem with the given fields replaced by the non-null parameter values.
no setterinherited
hasCheckbox → bool?
Optional. True, if the item has a checkbox
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isChecked → bool?
Optional. True, if the item has a checked checkbox
no setterinherited
label → String
Label of the item
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
Optional. For ordered lists, the type of the item label
no setterinherited
value → int?
Optional. For ordered lists, the numeric value of the item label
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_RichBlockListItem value)) → TResult

Available on RichBlockListItem, provided by the RichBlockListItemPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_RichBlockListItem value)?) → TResult?

Available on RichBlockListItem, provided by the RichBlockListItemPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_RichBlockListItem value)?, {required TResult orElse()}) → TResult

Available on RichBlockListItem, provided by the RichBlockListItemPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this RichBlockListItem to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited