RichBlockTableCell class abstract

Cell in a table.

Available extensions
Annotations
  • @freezed

Constructors

RichBlockTableCell({@JsonKey.new(name: 'text') @RichTextConverter() RichText? text, @JsonKey.new(name: 'is_header') bool? isHeader, @JsonKey.new(name: 'colspan') int? colspan, @JsonKey.new(name: 'rowspan') int? rowspan, @JsonKey.new(name: 'align') required String align, @JsonKey.new(name: 'valign') required String valign})
Cell in a table.
const
factory
RichBlockTableCell.fromJson(Map<String, dynamic> json)
Creates a RichBlockTableCell object from JSON.
factory

Properties

align String
Horizontal cell content alignment. Currently, must be one of “left”, “center”, or “right”.
no setterinherited
colspan int?
Optional. The number of columns the cell spans if it is bigger than 1
no setterinherited
copyWith → $RichBlockTableCellCopyWith<RichBlockTableCell>
Create a copy of RichBlockTableCell with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isHeader bool?
Optional. True, if the cell is a header cell
no setterinherited
rowspan int?
Optional. The number of rows the cell spans if it is bigger than 1
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text RichText?
Optional. Text in the cell. If omitted, then the cell is invisible.
no setterinherited
valign String
Vertical cell content alignment. Currently, must be one of “top”, “middle”, or “bottom”.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_RichBlockTableCell value)) → TResult

Available on RichBlockTableCell, provided by the RichBlockTableCellPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_RichBlockTableCell value)?) → TResult?

Available on RichBlockTableCell, provided by the RichBlockTableCellPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_RichBlockTableCell value)?, {required TResult orElse()}) → TResult

Available on RichBlockTableCell, provided by the RichBlockTableCellPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this RichBlockTableCell to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited