RichBlockTableCell constructor

const RichBlockTableCell({
  1. @JsonKey.new(name: 'text') @RichTextConverter() RichText? text,
  2. @JsonKey.new(name: 'is_header') bool? isHeader,
  3. @JsonKey.new(name: 'colspan') int? colspan,
  4. @JsonKey.new(name: 'rowspan') int? rowspan,
  5. @JsonKey.new(name: 'align') required String align,
  6. @JsonKey.new(name: 'valign') required String valign,
})

Cell in a table.

Implementation

const factory RichBlockTableCell({
  /// Optional. Text in the cell. If omitted, then the cell is invisible.
  @JsonKey(name: 'text') @RichTextConverter() RichText? text,

  /// Optional. True, if the cell is a header cell
  @JsonKey(name: 'is_header') bool? isHeader,

  /// Optional. The number of columns the cell spans if it is bigger than 1
  @JsonKey(name: 'colspan') int? colspan,

  /// Optional. The number of rows the cell spans if it is bigger than 1
  @JsonKey(name: 'rowspan') int? rowspan,

  /// Horizontal cell content alignment. Currently, must be one of “left”, “center”, or “right”.
  @JsonKey(name: 'align') required String align,

  /// Vertical cell content alignment. Currently, must be one of “top”, “middle”, or “bottom”.
  @JsonKey(name: 'valign') required String valign,
}) = _RichBlockTableCell;