colspan property
Optional. The number of columns the cell spans if it is bigger than 1
Implementation
@JsonKey(name: 'colspan')
int? get colspan;
Optional. The number of columns the cell spans if it is bigger than 1
@JsonKey(name: 'colspan')
int? get colspan;