rowspan property
Optional. The number of rows the cell spans if it is bigger than 1
Implementation
@JsonKey(name: 'rowspan')
int? get rowspan;
Optional. The number of rows the cell spans if it is bigger than 1
@JsonKey(name: 'rowspan')
int? get rowspan;