style property

  1. @JsonKey.new(name: 'style')
StyleType? get style
inherited

Optional. Style of the button. Must be one of “danger”, “success”, “primary”, or “link” (the button is shown as a regular link without borders). Apps may use theme-specific colors for the button background and text based on the style. The style “link” is allowed only for callback buttons.

Implementation

@JsonKey(name: 'style')
StyleType? get style;