url property

  1. @JsonKey.new(name: 'url')
String? get url
inherited

Optional. HTTP or tg:// URL to be opened when the button is pressed. Links tg://user?id=<user_id> can be used to mention a user by their identifier without using a username, if this is allowed by their privacy settings.

Implementation

@JsonKey(name: 'url')
String? get url;