SentGuestMessage class abstract

Describes an inline message sent by a guest bot.

Available extensions
Annotations
  • @freezed

Constructors

SentGuestMessage({@JsonKey.new(name: 'inline_message_id') required String inlineMessageId})
Creates a new SentGuestMessage object.
const
factory
SentGuestMessage.fromJson(Map<String, dynamic> json)
Creates a new SentGuestMessage object from a JSON Map.
factory

Properties

copyWith → $SentGuestMessageCopyWith<SentGuestMessage>
Create a copy of SentGuestMessage with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
inlineMessageId String
Identifier of the sent inline message.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SentGuestMessage value)) → TResult

Available on SentGuestMessage, provided by the SentGuestMessagePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SentGuestMessage value)?) → TResult?

Available on SentGuestMessage, provided by the SentGuestMessagePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SentGuestMessage value)?, {required TResult orElse()}) → TResult

Available on SentGuestMessage, provided by the SentGuestMessagePatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SentGuestMessage to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited