SentWebAppMessage class abstract

Describes an inline message sent by a Web App on behalf of a user.

Annotations
  • @freezed

Constructors

SentWebAppMessage({@JsonKey.new(name: 'inline_message_id') String? inlineMessageId})
Creates an inline message sent by a Web App
const
factory
SentWebAppMessage.fromJson(Map<String, dynamic> json)
Creates a SentWebAppMessage from a JSON map
factory

Properties

copyWith → $SentWebAppMessageCopyWith<SentWebAppMessage>
Create a copy of SentWebAppMessage with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inlineMessageId → String?
Optional. Identifier of the sent inline message. Available only if there is an inline keyboard attached to the message.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SentWebAppMessage to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited