ShippingAddress class abstract

This object represents a shipping address.

Annotations
  • @freezed

Constructors

ShippingAddress({@JsonKey.new(name: 'country_code') required String countryCode, @JsonKey.new(name: 'state') required String state, @JsonKey.new(name: 'city') required String city, @JsonKey.new(name: 'street_line1') required String streetLine1, @JsonKey.new(name: 'street_line2') required String streetLine2, @JsonKey.new(name: 'post_code') required String postCode})
Constructs a ShippingAddress object
const
factory
ShippingAddress.fromJson(Map<String, dynamic> json)
Creates a ShippingAddress object from JSON object
factory

Properties

city → String
City
no setterinherited
copyWith → $ShippingAddressCopyWith<ShippingAddress>
Create a copy of ShippingAddress with the given fields replaced by the non-null parameter values.
no setterinherited
countryCode → String
ISO 3166-1 alpha-2 country code
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
postCode → String
Address post code
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String
State, if applicable
no setterinherited
streetLine1 → String
First line for the address
no setterinherited
streetLine2 → String
Second line for the address
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ShippingAddress to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited