isBurned property
Optional. True, if the gift was used to craft another gift and isn't available anymore
Implementation
@JsonKey(name: 'is_burned')
bool? get isBurned;
Optional. True, if the gift was used to craft another gift and isn't available anymore
@JsonKey(name: 'is_burned')
bool? get isBurned;