UniqueGiftBackdrop class abstract

This object describes the backdrop of a unique gift.

Annotations
  • @freezed

Constructors

UniqueGiftBackdrop({@JsonKey.new(name: 'name') required String name, @JsonKey.new(name: 'colors') required UniqueGiftBackdropColors colors, @JsonKey.new(name: 'rarity_per_mille') required int rarityPerMille})
Creates a new UniqueGiftBackdrop object.
const
factory
UniqueGiftBackdrop.fromJson(Map<String, dynamic> json)
Creates a new UniqueGiftBackdrop object from a JSON Map.
factory

Properties

colors → UniqueGiftBackdropColors
Colors of the backdrop
no setterinherited
copyWith → $UniqueGiftBackdropCopyWith<UniqueGiftBackdrop>
Create a copy of UniqueGiftBackdrop with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the backdrop
no setterinherited
rarityPerMille → int
The number of unique gifts that receive this backdrop for every 1000 gifts upgraded
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this UniqueGiftBackdrop to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited