UniqueGiftBackdropColors class abstract

This object describes the colors of the backdrop of a unique gift.

Annotations
  • @freezed

Constructors

UniqueGiftBackdropColors({@JsonKey.new(name: 'center_color') required int centerColor, @JsonKey.new(name: 'edge_color') required int edgeColor, @JsonKey.new(name: 'symbol_color') required int symbolColor, @JsonKey.new(name: 'text_color') required int textColor})
Creates a new UniqueGiftBackdropColors object.
const
factory
UniqueGiftBackdropColors.fromJson(Map<String, dynamic> json)
Creates a new UniqueGiftBackdropColors object from a JSON Map.
factory

Properties

centerColor → int
The color in the center of the backdrop in RGB format
no setterinherited
copyWith → $UniqueGiftBackdropColorsCopyWith<UniqueGiftBackdropColors>
Create a copy of UniqueGiftBackdropColors with the given fields replaced by the non-null parameter values.
no setterinherited
edgeColor → int
The color on the edges of the backdrop in RGB format
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbolColor → int
The color to be applied to the symbol in RGB format
no setterinherited
textColor → int
The color for the text on the backdrop in RGB format
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this UniqueGiftBackdropColors to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited