lastResaleCurrency property

  1. @JsonKey.new(name: 'last_resale_currency')
String? get lastResaleCurrency
inherited

Optional. For gifts bought from other users, the currency in which the payment for the gift was done. Currently, one of “XTR” for Telegram Stars or “TON” for toncoins.

Implementation

@JsonKey(name: 'last_resale_currency')
String? get lastResaleCurrency;