UniqueGiftModel constructor
const
UniqueGiftModel({
- @JsonKey.new(name: 'name') required String name,
- @JsonKey.new(name: 'sticker') required Sticker sticker,
- @JsonKey.new(name: 'rarity_per_mille') required int rarityPerMille,
- @JsonKey.new(name: 'rarity') RarityType? rarity,
Creates a new UniqueGiftModel object.
Implementation
const factory UniqueGiftModel({
/// Name of the model
@JsonKey(name: 'name') required String name,
/// The sticker that represents the unique gift
@JsonKey(name: 'sticker') required Sticker sticker,
/// The number of unique gifts that receive this model for every 1000 gifts upgraded
@JsonKey(name: 'rarity_per_mille') required int rarityPerMille,
/// Optional. Rarity of the model if it is a crafted model. Currently, can be “uncommon”, “rare”, “epic”, or “legendary”.
@JsonKey(name: 'rarity') RarityType? rarity,
}) = _UniqueGiftModel;