rarity property
Optional. Rarity of the model if it is a crafted model. Currently, can be “uncommon”, “rare”, “epic”, or “legendary”.
Implementation
@JsonKey(name: 'rarity')
RarityType? get rarity;
Optional. Rarity of the model if it is a crafted model. Currently, can be “uncommon”, “rare”, “epic”, or “legendary”.
@JsonKey(name: 'rarity')
RarityType? get rarity;