managedBot property
Optional. A new bot was created to be managed by the bot or token of a bot was changed
Implementation
@JsonKey(name: 'managed_bot')
ManagedBotUpdated? get managedBot;
Optional. A new bot was created to be managed by the bot or token of a bot was changed
@JsonKey(name: 'managed_bot')
ManagedBotUpdated? get managedBot;