allowsUsersToCreateTopics property
Optional. True, if the bot allows users to create and delete topics in private chats. Returned only in getMe.
Implementation
@JsonKey(name: 'allows_users_to_create_topics')
bool? get allowsUsersToCreateTopics;
Optional. True, if the bot allows users to create and delete topics in private chats. Returned only in getMe.
@JsonKey(name: 'allows_users_to_create_topics')
bool? get allowsUsersToCreateTopics;