canManageBots property
Optional. True, if other bots can be created to be controlled by the bot. Returned only in getMe.
Implementation
@JsonKey(name: 'can_manage_bots')
bool? get canManageBots;
Optional. True, if other bots can be created to be controlled by the bot. Returned only in getMe.
@JsonKey(name: 'can_manage_bots')
bool? get canManageBots;