Venue class abstract

This object represents a venue.

Annotations
  • @freezed

Constructors

Venue({@JsonKey.new(name: 'location') required Location location, @JsonKey.new(name: 'title') required String title, @JsonKey.new(name: 'address') required String address, @JsonKey.new(name: 'foursquare_id') String? foursquareId, @JsonKey.new(name: 'foursquare_type') String? foursquareType, @JsonKey.new(name: 'google_place_id') String? googlePlaceId, @JsonKey.new(name: 'google_place_type') String? googlePlaceType})
Constructs a Venue object
const
factory
Venue.fromJson(Map<String, dynamic> json)
Creates a Venue object from JSON object
factory

Properties

address → String
Address of the venue
no setterinherited
copyWith → $VenueCopyWith<Venue>
Create a copy of Venue with the given fields replaced by the non-null parameter values.
no setterinherited
foursquareId → String?
Optional. Foursquare identifier of the venue
no setterinherited
foursquareType → String?
Optional. Foursquare type of the venue. (For example, "arts_entertainment/default", "arts_entertainment/aquarium" or "food/icecream".)
no setterinherited
googlePlaceId → String?
Optional. Google Places identifier of the venue
no setterinherited
googlePlaceType → String?
Optional. Google Places type of the venue. (See supported types.)
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
location → Location
Venue location
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
Name of the venue
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Venue to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited