VideoChatEnded class abstract

This object represents a service message about a video chat ended in the chat.

Available extensions
Annotations
  • @freezed

Constructors

VideoChatEnded({@JsonKey.new(name: 'duration') required int duration})
Constructs a new VideoChatEnded instance
const
factory
VideoChatEnded.fromJson(Map<String, dynamic> json)
Creates a VideoChatEnded object from JSON object
factory

Properties

copyWith → $VideoChatEndedCopyWith<VideoChatEnded>
Create a copy of VideoChatEnded with the given fields replaced by the non-null parameter values.
no setterinherited
duration → int
Video chat duration in seconds
no setterinherited
durationTime → Duration

Available on VideoChatEnded, provided by the VideoChatEndedExt extension

Duration object of duration field
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this VideoChatEnded to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited