VideoChatParticipantsInvited class abstract

This object represents a service message about new members invited to a video chat.

Annotations
  • @freezed

Constructors

VideoChatParticipantsInvited({@JsonKey.new(name: 'users') required List<User> users})
Constructs a VideoChatParticipantsInvited object.
const
factory
VideoChatParticipantsInvited.fromJson(Map<String, dynamic> json)
Creates a VideoChatParticipantsInvited object from JSON object.
factory

Properties

copyWith → $VideoChatParticipantsInvitedCopyWith<VideoChatParticipantsInvited>
Create a copy of VideoChatParticipantsInvited with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
users → List<User>
New members that were invited to the video chat.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this VideoChatParticipantsInvited to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited