VideoQuality class abstract

This object represents a video file of a specific quality.

Available extensions
Annotations
  • @freezed

Constructors

VideoQuality({@JsonKey.new(name: 'file_id') required String fileId, @JsonKey.new(name: 'file_unique_id') required String fileUniqueId, required int width, required int height, required String codec, @JsonKey.new(name: 'file_size') int? fileSize})
Creates a new VideoQuality instance.
const
factory
VideoQuality.fromJson(Map<String, dynamic> json)
Creates a VideoQuality object from JSON object.
factory

Properties

codec String
Codec that was used to encode the video, for example, “h264”, “h265”, or “av01”
no setterinherited
copyWith → $VideoQualityCopyWith<VideoQuality>
Create a copy of VideoQuality with the given fields replaced by the non-null parameter values.
no setterinherited
fileId String
Identifier for this file, which can be used to download or reuse the file
no setterinherited
fileSize int?
Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.
no setterinherited
fileUniqueId String
Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
height int
Video height
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Video width
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VideoQuality value)) → TResult

Available on VideoQuality, provided by the VideoQualityPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VideoQuality value)?) → TResult?

Available on VideoQuality, provided by the VideoQualityPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VideoQuality value)?, {required TResult orElse()}) → TResult

Available on VideoQuality, provided by the VideoQualityPatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this VideoQuality to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited