WebAppInfo class abstract

Describes a Web App.

Annotations
  • @freezed

Constructors

WebAppInfo({@JsonKey.new(name: 'url') required String url})
Constructs a WebAppInfo object
const
factory
WebAppInfo.fromJson(Map<String, dynamic> json)
Creates a WebAppInfo object from JSON object
factory

Properties

copyWith → $WebAppInfoCopyWith<WebAppInfo>
Create a copy of WebAppInfo with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
An HTTPS URL of a Web App to be opened with additional data as specified in Initializing Web Apps
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this WebAppInfo to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited