WriteAccessAllowed class abstract

This object represents a service message about a user allowing a bot added to the attachment menu to write messages.

Annotations
  • @freezed

Constructors

WriteAccessAllowed({@JsonKey.new(name: 'web_app_name') String? webAppName, @JsonKey.new(name: 'from_request') bool? fromRequest, @JsonKey.new(name: 'from_attachment_menu') bool? fromAttachmentMenu})
Constructs a WriteAccessAllowed object.
const
factory
WriteAccessAllowed.fromJson(Map<String, dynamic> json)
Creates a WriteAccessAllowed object from JSON object.
factory

Properties

copyWith → $WriteAccessAllowedCopyWith<WriteAccessAllowed>
Create a copy of WriteAccessAllowed with the given fields replaced by the non-null parameter values.
no setterinherited
fromAttachmentMenu → bool?
Optional. True, if the access was granted when the bot was added to the attachment or side menu
no setterinherited
fromRequest → bool?
Optional. True, if the access was granted after the user accepted an explicit request from a Web App sent by the method requestWriteAccess
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webAppName → String?
Name of the connected website. Present only if the user allowed the bot to send them messages.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this WriteAccessAllowed to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited