ChatID class
This class is used to represent a chat id. It is a subclass of ID.
When the chat id is an integer, you can use this class to represent the chat id.
Constructors
-
ChatID(int id)
-
Creates a new ChatID object with the passed
id which is an integer.
const
-
ChatID.create(int id)
-
Creates a new ChatID object with the passed
id which is an integer.
factory
Properties
-
hashCode
→ int
-
Returns the hash code of the id.
no setterinherited
-
id
→ int
-
The ID getter, returns the actual integer value
no setteroverride
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ dynamic
-
Returns the id as a string or an integer.
inherited
-
toString()
→ String
-
A string representation of this object.
override
Operators
-
operator ==(Object other)
→ bool
-
Equality operator. Returns
true if the passed other is an ID and the id of the other is equal to the id of this ID.
inherited