get<T> method

T? get<T>(
  1. String key
)

Gets a property value by key.

This is used by middleware and plugins to store and retrieve data that needs to persist during the processing of an update.

Example:

final sessionData = ctx.get<Map<String, dynamic>>('session');

Implementation

T? get<T>(String key) => _properties[key] as T?;