stoppedMessageGeneration property

MessageGenerationStopped? get stoppedMessageGeneration

The stopped message generation update, if any.

This will be non-null when a user asked the bot to stop the generation of a message draft sent with canStop: true.

Implementation

MessageGenerationStopped? get stoppedMessageGeneration =>
    update.stoppedMessageGeneration;