Filter<CTX extends Context> class abstract

Base class for all filters.

Filters are used to determine whether middleware should be executed based on the current context. They provide a clean way to conditionally execute middleware based on various criteria.

Implementers

Constructors

Filter()
Abstract const constructor
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(Filter<CTX> other) Filter<CTX>
Combines this filter with another using logical AND.
matches(CTX ctx) bool
Tests if this filter matches the given context.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() Filter<CTX>
Creates a filter that matches the opposite of this filter.
or(Filter<CTX> other) Filter<CTX>
Combines this filter with another using logical OR.
toString() String
A string representation of this object.
inherited

Operators

operator *(Filter<CTX> other) Filter<CTX>
Combines this filter with another using logical AND.
operator +(Filter<CTX> other) Filter<CTX>
Combines this filter with another using logical OR.
operator -(Filter<CTX> other) Filter<CTX>
Creates a filter that matches this AND not the other.
operator ==(Object other) bool
The equality operator.
inherited
operator unary-() Filter<CTX>
Creates a filter that matches the opposite of this filter.