isEphemeral property
Optional. True, if the command sends an ephemeral message, which can be seen only by the sender of the message and the bot
Implementation
@JsonKey(name: 'is_ephemeral')
bool? get isEphemeral;
Optional. True, if the command sends an ephemeral message, which can be seen only by the sender of the message and the bot
@JsonKey(name: 'is_ephemeral')
bool? get isEphemeral;