ChatOwnerLeft class abstract
Describes a service message about the chat owner leaving the chat.
Since: Bot API 9.4
- Available extensions
- Annotations
-
- @freezed
Constructors
- ChatOwnerLeft({@JsonKey.new(name: 'new_owner') User? newOwner})
-
Creates a ChatOwnerLeft instance
constfactory
-
ChatOwnerLeft.fromJson(Map<
String, dynamic> json) -
Creates a ChatOwnerLeft from a JSON map
factory
Properties
-
copyWith
→ $ChatOwnerLeftCopyWith<
ChatOwnerLeft> -
Create a copy of ChatOwnerLeft
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- newOwner → User?
-
Optional. The user which will be the new owner of the chat if the
previous owner does not return to the chat.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ChatOwnerLeft value)) → TResult -
Available on ChatOwnerLeft, provided by the ChatOwnerLeftPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ChatOwnerLeft value)?) → TResult? -
Available on ChatOwnerLeft, provided by the ChatOwnerLeftPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ChatOwnerLeft value)?, {required TResult orElse()}) → TResult -
Available on ChatOwnerLeft, provided by the ChatOwnerLeftPatterns extension
A variant ofmapthat fallback to returningorElse. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ChatOwnerLeft to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited