newOwner property
Optional. The user which will be the new owner of the chat if the previous owner does not return to the chat.
Implementation
@JsonKey(name: 'new_owner')
User? get newOwner;
Optional. The user which will be the new owner of the chat if the previous owner does not return to the chat.
@JsonKey(name: 'new_owner')
User? get newOwner;