receiverUserId property
Identifier of the user who will receive the message. It is not guaranteed that the user will receive the message, especially if they are offline.
Implementation
@JsonKey(name: 'receiver_user_id')
int get receiverUserId;
Identifier of the user who will receive the message. It is not guaranteed that the user will receive the message, especially if they are offline.
@JsonKey(name: 'receiver_user_id')
int get receiverUserId;