InputMediaLink class abstract
Represents an HTTP link to be sent.
- Implemented types
- Available extensions
- Annotations
-
- @Freezed.new(fromJson: false, toJson: true)
Constructors
- InputMediaLink({@JsonKey.new(name: 'type') @Default.new(InputMediaType.link) InputMediaType type, @JsonKey.new(name: 'url') required String url})
-
Creates a new InputMediaLink object.
constfactory
Properties
-
copyWith
→ $InputMediaLinkCopyWith<
InputMediaLink> -
Create a copy of InputMediaLink
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → InputMediaType
-
Type of the media, must be link
no setterinherited
- url → String
-
HTTP URL of the link
no setterinherited
Methods
-
getInputFiles(
) → Iterable< InputFile?> - Returns an iterable of files
-
map<
TResult extends Object?> (TResult $default(_InputMediaLink value)) → TResult -
Available on InputMediaLink, provided by the InputMediaLinkPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_InputMediaLink value)?) → TResult? -
Available on InputMediaLink, provided by the InputMediaLinkPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_InputMediaLink value)?, {required TResult orElse()}) → TResult -
Available on InputMediaLink, provided by the InputMediaLinkPatterns extension
A variant ofmapthat fallback to returningorElse. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this InputMediaLink to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited