InputMediaVenue class abstract

Represents a venue to be sent.

Implemented types
Available extensions
Annotations
  • @Freezed.new(fromJson: false, toJson: true)

Constructors

InputMediaVenue({@JsonKey.new(name: 'type') @Default.new(InputMediaType.venue) InputMediaType type, @JsonKey.new(name: 'latitude') required double latitude, @JsonKey.new(name: 'longitude') required double longitude, @JsonKey.new(name: 'title') required String title, @JsonKey.new(name: 'address') required String address, @JsonKey.new(name: 'foursquare_id') String? foursquareId, @JsonKey.new(name: 'foursquare_type') String? foursquareType, @JsonKey.new(name: 'google_place_id') String? googlePlaceId, @JsonKey.new(name: 'google_place_type') String? googlePlaceType})
Creates a new InputMediaVenue object.
const
factory

Properties

address String
Address of the venue
no setterinherited
copyWith → $InputMediaVenueCopyWith<InputMediaVenue>
Create a copy of InputMediaVenue with the given fields replaced by the non-null parameter values.
no setterinherited
foursquareId String?
Optional. Foursquare identifier of the venue
no setterinherited
foursquareType String?
Optional. Foursquare type of the venue, if known.
no setterinherited
googlePlaceId String?
Optional. Google Places identifier of the venue
no setterinherited
googlePlaceType String?
Optional. Google Places type of the venue.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
latitude double
Latitude of the location
no setterinherited
longitude double
Longitude of the location
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Name of the venue
no setterinherited
type InputMediaType
Type of the media, must be venue
no setterinherited

Methods

getInputFiles() Iterable<InputFile?>
Returns an iterable of files
map<TResult extends Object?>(TResult $default(_InputMediaVenue value)) → TResult

Available on InputMediaVenue, provided by the InputMediaVenuePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_InputMediaVenue value)?) → TResult?

Available on InputMediaVenue, provided by the InputMediaVenuePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_InputMediaVenue value)?, {required TResult orElse()}) → TResult

Available on InputMediaVenue, provided by the InputMediaVenuePatterns extension

A variant of map that fallback to returning orElse.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this InputMediaVenue to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited