InputRichBlockListItem class abstract
An item of a list to be sent.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
InputRichBlockListItem({@JsonKey.new(name: 'blocks') required List<
InputRichBlock> blocks, @JsonKey.new(name: 'has_checkbox') bool? hasCheckbox, @JsonKey.new(name: 'is_checked') bool? isChecked, @JsonKey.new(name: 'value') int? value, @JsonKey.new(name: 'type') String? type}) -
Creates a new InputRichBlockListItem object.
constfactory
-
InputRichBlockListItem.fromJson(Map<
String, dynamic> json) -
Creates a InputRichBlockListItem object from JSON.
factory
Properties
-
blocks
→ List<
InputRichBlock> -
The content of the item
no setterinherited
-
copyWith
→ $InputRichBlockListItemCopyWith<
InputRichBlockListItem> -
Create a copy of InputRichBlockListItem
with the given fields replaced by the non-null parameter values.
no setterinherited
- hasCheckbox → bool?
-
Optional. Pass True if the item has a checkbox
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isChecked → bool?
-
Optional. Pass True if the item has a checked checkbox
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Optional. For ordered lists, the type of the item label; must be one of
“a” for lowercase letters, “A” for uppercase letters, “i” for lowercase
Roman numerals, “I” for uppercase Roman numerals, or “1” for decimal
numbers
no setterinherited
- value → int?
-
Optional. For ordered lists, the numeric value of the item label
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_InputRichBlockListItem value)) → TResult -
Available on InputRichBlockListItem, provided by the InputRichBlockListItemPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_InputRichBlockListItem value)?) → TResult? -
Available on InputRichBlockListItem, provided by the InputRichBlockListItemPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_InputRichBlockListItem value)?, {required TResult orElse()}) → TResult -
Available on InputRichBlockListItem, provided by the InputRichBlockListItemPatterns extension
A variant ofmapthat fallback to returningorElse. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this InputRichBlockListItem to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited