InputRichMessage class abstract
Describes a rich message to be sent. Exactly one of the fields html or markdown must be used.
- Available extensions
- Annotations
-
- @freezed
Constructors
- InputRichMessage({@JsonKey.new(name: 'html') String? html, @JsonKey.new(name: 'markdown') String? markdown, @JsonKey.new(name: 'is_rtl') bool? isRtl, @JsonKey.new(name: 'skip_entity_detection') bool? skipEntityDetection})
-
Describes a rich message to be sent. Exactly one of the fields html or markdown must be used.
constfactory
-
InputRichMessage.fromJson(Map<
String, dynamic> json) -
Creates a InputRichMessage object from JSON.
factory
Properties
-
copyWith
→ $InputRichMessageCopyWith<
InputRichMessage> -
Create a copy of InputRichMessage
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- html → String?
-
Optional. Content of the rich message to send described using HTML formatting. See rich message formatting options for more details.
no setterinherited
- isRtl → bool?
-
Optional. Pass True if the rich message must be shown right-to-left
no setterinherited
- markdown → String?
-
Optional. Content of the rich message to send described using Markdown formatting. See rich message formatting options for more details.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipEntityDetection → bool?
-
Optional. Pass True to skip automatic detection of entities (e.g., URLs, email addresses, username mentions, hashtags, cashtags, bot commands, or phone numbers) in the text
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_InputRichMessage value)) → TResult -
Available on InputRichMessage, provided by the InputRichMessagePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_InputRichMessage value)?) → TResult? -
Available on InputRichMessage, provided by the InputRichMessagePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_InputRichMessage value)?, {required TResult orElse()}) → TResult -
Available on InputRichMessage, provided by the InputRichMessagePatterns extension
A variant ofmapthat fallback to returningorElse. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this InputRichMessage to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited