InputRichMessage constructor
const
InputRichMessage({
- @JsonKey.new(name: 'html') String? html,
- @JsonKey.new(name: 'markdown') String? markdown,
- @JsonKey.new(name: 'is_rtl') bool? isRtl,
- @JsonKey.new(name: 'skip_entity_detection') bool? skipEntityDetection,
- @JsonKey.new(name: 'media') List<
InputRichMessageMedia> ? media, - @JsonKey.new(name: 'blocks') List<
InputRichBlock> ? blocks,
Describes a rich message to be sent. Exactly one of the fields html or markdown must be used.
Implementation
const factory InputRichMessage({
/// Optional. Content of the rich message to send described using HTML formatting. See rich message formatting options for more details.
@JsonKey(name: 'html') String? html,
/// Optional. Content of the rich message to send described using Markdown formatting. See rich message formatting options for more details.
@JsonKey(name: 'markdown') String? markdown,
/// Optional. Pass True if the rich message must be shown right-to-left
@JsonKey(name: 'is_rtl') bool? isRtl,
/// Optional. Pass True to skip automatic detection of entities (e.g., URLs, email addresses, username mentions, hashtags, cashtags, bot commands, or phone numbers) in the text
@JsonKey(name: 'skip_entity_detection') bool? skipEntityDetection,
/// Optional. List of media that are specified in the markdown or html fields using tg://photo?id=, tg://video?id=, and tg://audio?id= links
@JsonKey(name: 'media') List<InputRichMessageMedia>? media,
/// Optional. Content of the rich message to send described as a list of blocks
@JsonKey(name: 'blocks') List<InputRichBlock>? blocks,
}) = _InputRichMessage;