InputRichMessage constructor

const InputRichMessage({
  1. @JsonKey.new(name: 'html') String? html,
  2. @JsonKey.new(name: 'markdown') String? markdown,
  3. @JsonKey.new(name: 'is_rtl') bool? isRtl,
  4. @JsonKey.new(name: 'skip_entity_detection') bool? skipEntityDetection,
})

Describes a rich message to be sent. Exactly one of the fields html or markdown must be used.

Implementation

const factory InputRichMessage({
  /// Optional. Content of the rich message to send described using HTML formatting. See rich message formatting options for more details.
  @JsonKey(name: 'html') String? html,

  /// Optional. Content of the rich message to send described using Markdown formatting. See rich message formatting options for more details.
  @JsonKey(name: 'markdown') String? markdown,

  /// Optional. Pass True if the rich message must be shown right-to-left
  @JsonKey(name: 'is_rtl') bool? isRtl,

  /// Optional. Pass True to skip automatic detection of entities (e.g., URLs, email addresses, username mentions, hashtags, cashtags, bot commands, or phone numbers) in the text
  @JsonKey(name: 'skip_entity_detection') bool? skipEntityDetection,
}) = _InputRichMessage;