InputRichMessageMedia class abstract
Describes a media element embedded in an outgoing rich message.
- Available extensions
- Annotations
-
- @freezed
Constructors
- InputRichMessageMedia({@JsonKey.new(name: 'id') required String id, @JsonKey.new(name: 'media') required InputMedia media})
-
Describes a media element embedded in an outgoing rich message.
constfactory
-
InputRichMessageMedia.fromJson(Map<
String, dynamic> json) -
Creates a InputRichMessageMedia object from JSON.
factory
Properties
-
copyWith
→ $InputRichMessageMediaCopyWith<
InputRichMessageMedia> -
Create a copy of InputRichMessageMedia
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier of the media used in a tg://photo?id=, tg://video?id=,
or tg://audio?id= link. 1-64 characters, only A-Z, a-z, 0-9, _ and - are
allowed.
no setterinherited
- media → InputMedia
-
The media to be sent. Everything except the media itself and its
properties is ignored.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getInputFiles(
) → Iterable< InputFile?> - Returns an iterable of files
-
map<
TResult extends Object?> (TResult $default(_InputRichMessageMedia value)) → TResult -
Available on InputRichMessageMedia, provided by the InputRichMessageMediaPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_InputRichMessageMedia value)?) → TResult? -
Available on InputRichMessageMedia, provided by the InputRichMessageMediaPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_InputRichMessageMedia value)?, {required TResult orElse()}) → TResult -
Available on InputRichMessageMedia, provided by the InputRichMessageMediaPatterns extension
A variant ofmapthat fallback to returningorElse. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this InputRichMessageMedia to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited