KeyboardButtonRequestManagedBot class abstract
This object defines the parameters for the creation of a managed bot.
Information about the created bot will be shared with the bot using the
update managed_bot and a Message with the field managed_bot_created.
- Available extensions
- Annotations
-
- @freezed
Constructors
- KeyboardButtonRequestManagedBot({@JsonKey.new(name: 'request_id') required int requestId, @JsonKey.new(name: 'suggested_name') String? suggestedName, @JsonKey.new(name: 'suggested_username') String? suggestedUsername})
-
Creates a new KeyboardButtonRequestManagedBot object.
constfactory
-
KeyboardButtonRequestManagedBot.fromJson(Map<
String, dynamic> json) -
Creates a new KeyboardButtonRequestManagedBot from a JSON object.
factory
Properties
-
copyWith
→ $KeyboardButtonRequestManagedBotCopyWith<
KeyboardButtonRequestManagedBot> -
Create a copy of KeyboardButtonRequestManagedBot
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestId → int
-
Signed 32-bit identifier of the request. Must be unique within the
message.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestedName → String?
-
Optional. Suggested name for the bot.
no setterinherited
- suggestedUsername → String?
-
Optional. Suggested username for the bot.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_KeyboardButtonRequestManagedBot value)) → TResult -
Available on KeyboardButtonRequestManagedBot, provided by the KeyboardButtonRequestManagedBotPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_KeyboardButtonRequestManagedBot value)?) → TResult? -
Available on KeyboardButtonRequestManagedBot, provided by the KeyboardButtonRequestManagedBotPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_KeyboardButtonRequestManagedBot value)?, {required TResult orElse()}) → TResult -
Available on KeyboardButtonRequestManagedBot, provided by the KeyboardButtonRequestManagedBotPatterns extension
A variant ofmapthat fallback to returningorElse. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this KeyboardButtonRequestManagedBot to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited