guestBotCallerChat property
Optional. For a message sent by a guest bot, this is the chat whose original message triggered the bot's response
Implementation
@JsonKey(name: 'guest_bot_caller_chat')
Chat? get guestBotCallerChat;
Optional. For a message sent by a guest bot, this is the chat whose original message triggered the bot's response
@JsonKey(name: 'guest_bot_caller_chat')
Chat? get guestBotCallerChat;