guestBotCallerUser property
Optional. For a message sent by a guest bot, this is the user whose original message triggered the bot's response
Implementation
@JsonKey(name: 'guest_bot_caller_user')
User? get guestBotCallerUser;
Optional. For a message sent by a guest bot, this is the user whose original message triggered the bot's response
@JsonKey(name: 'guest_bot_caller_user')
User? get guestBotCallerUser;