guestQueryId property
Optional. The unique identifier for the guest query. Use this identifier with the method answerGuestQuery to send a response message. If non-empty, the message belongs to the chat where the guest bot was summoned, which may not coincide with other existing bot chats sharing the same identifier.
Implementation
@JsonKey(name: 'guest_query_id')
String? get guestQueryId;