livePhoto property
Optional. Message is a live photo, information about the live photo. For backward compatibility, when this field is set, the photo field will also be set.
Implementation
@JsonKey(name: 'live_photo')
LivePhoto? get livePhoto;
Optional. Message is a live photo, information about the live photo. For backward compatibility, when this field is set, the photo field will also be set.
@JsonKey(name: 'live_photo')
LivePhoto? get livePhoto;