ephemeralMessageId property
Identifier of the incoming ephemeral message that will be replied to in the current chat. A reply to an ephemeral message must itself be an ephemeral message. An ephemeral message may only be replied to within 15 seconds of being sent. Required if message_id isn't specified.
Implementation
@JsonKey(name: 'ephemeral_message_id')
int? get ephemeralMessageId;