messageId property
Identifier of the message that will be replied to in the current chat, or in the chat chat_id if it is specified. Required if ephemeral_message_id isn't specified.
Implementation
@JsonKey(name: 'message_id')
int? get messageId;
Identifier of the message that will be replied to in the current chat, or in the chat chat_id if it is specified. Required if ephemeral_message_id isn't specified.
@JsonKey(name: 'message_id')
int? get messageId;