RichBlock.details constructor
const
RichBlock.details({
- @JsonKey.new(name: 'type') @Default.new(RichBlockType.details) RichBlockType type,
- @JsonKey.new(name: 'summary') @RichTextConverter() required RichText summary,
- @JsonKey.new(name: 'blocks') required List<
RichBlock> blocks, - @JsonKey.new(name: 'is_open') bool? isOpen,
An expandable block for details disclosure, corresponding to the HTML tag <details>.
Implementation
const factory RichBlock.details({
/// Type of the block, always "details"
@JsonKey(name: 'type') @Default(RichBlockType.details) RichBlockType type,
/// Always shown summary of the block
@JsonKey(name: 'summary') @RichTextConverter() required RichText summary,
/// Content of the block
@JsonKey(name: 'blocks') required List<RichBlock> blocks,
/// Optional. True, if the content of the block is visible by default
@JsonKey(name: 'is_open') bool? isOpen,
}) = RichBlockDetails;