RichBlockListItem constructor
const
RichBlockListItem({})
An item of a list.
Implementation
const factory RichBlockListItem({
/// Label of the item
@JsonKey(name: 'label') required String label,
/// The content of the item
@JsonKey(name: 'blocks') required List<RichBlock> blocks,
/// Optional. True, if the item has a checkbox
@JsonKey(name: 'has_checkbox') bool? hasCheckbox,
/// Optional. True, if the item has a checked checkbox
@JsonKey(name: 'is_checked') bool? isChecked,
/// Optional. For ordered lists, the numeric value of the item label
@JsonKey(name: 'value') int? value,
/// Optional. For ordered lists, the type of the item label
@JsonKey(name: 'type') String? type,
}) = _RichBlockListItem;