RichBlockType enum
Type of the rich block.
Values
- paragraph → const RichBlockType
-
A text paragraph, corresponding to the HTML tag
.
const RichBlockType("paragraph") - heading → const RichBlockType
-
A section heading, corresponding to the HTML tags
,
,
,
,
, or
.
const RichBlockType("heading") - pre → const RichBlockType
-
A preformatted text block, corresponding to the nested HTML tags
and
.const RichBlockType("pre") -
A footer, corresponding to the HTML tag
const RichBlockType("footer") - divider → const RichBlockType
-
A divider, corresponding to the HTML tag
.const RichBlockType("divider") - mathematicalExpression → const RichBlockType
-
A block with a mathematical expression in LaTeX format, corresponding to the custom HTML tag <tg-math-block>.
const RichBlockType("mathematical_expression") - anchor → const RichBlockType
-
A block with an anchor, corresponding to the HTML tag with the attribute name.
const RichBlockType("anchor") - list → const RichBlockType
-
A list of blocks, corresponding to the HTML tag
- or
- .
- with multiple nested tags
const RichBlockType("list") - blockquote → const RichBlockType
-
A block quotation, corresponding to the HTML tag <blockquote>.
const RichBlockType("blockquote") - pullquote → const RichBlockType
-
A quotation with centered text, loosely corresponding to the HTML tag <aside>.
const RichBlockType("pullquote") - collage → const RichBlockType
-
A collage, corresponding to the custom HTML tag <tg-collage>.
const RichBlockType("collage") - slideshow → const RichBlockType
-
A slideshow, corresponding to the custom HTML tag <tg-slideshow>.
const RichBlockType("slideshow") - table → const RichBlockType
-
A table, corresponding to the HTML tag <table>.
const RichBlockType("table") - details → const RichBlockType
-
An expandable block for details disclosure, corresponding to the HTML tag <details>.
const RichBlockType("details") - map → const RichBlockType
-
A block with a map, corresponding to the custom HTML tag <tg-map>.
const RichBlockType("map") - animation → const RichBlockType
-
A block with an animation, corresponding to the HTML tag <video>.
const RichBlockType("animation") - audio → const RichBlockType
-
A block with a music file, corresponding to the HTML tag <audio>.
const RichBlockType("audio") - photo → const RichBlockType
-
A block with a photo, corresponding to the HTML tag <photo>.
const RichBlockType("photo") - video → const RichBlockType
-
A block with a video, corresponding to the HTML tag <video>.
const RichBlockType("video") - voiceNote → const RichBlockType
-
A block with a voice note, corresponding to the HTML tag <audio>.
const RichBlockType("voice_note") - thinking → const RichBlockType
-
A block with a “Thinking…” placeholder, corresponding to the custom HTML tag <tg-thinking>.
const RichBlockType("thinking")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The value of the enum.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts a RichBlockType to a string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RichBlockType> - A constant List of the values in this enum, in order of their declaration.