RichMessage class abstract
Rich formatted message.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
RichMessage({@JsonKey.new(name: 'blocks') required List<
RichBlock> blocks, @JsonKey.new(name: 'is_rtl') bool? isRtl}) -
Rich formatted message.
constfactory
-
RichMessage.fromJson(Map<
String, dynamic> json) -
Creates a RichMessage object from JSON.
factory
Properties
-
blocks
→ List<
RichBlock> -
Content of the message
no setterinherited
-
copyWith
→ $RichMessageCopyWith<
RichMessage> -
Create a copy of RichMessage
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRtl → bool?
-
Optional. True, if the rich message must be shown right-to-left
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_RichMessage value)) → TResult -
Available on RichMessage, provided by the RichMessagePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_RichMessage value)?) → TResult? -
Available on RichMessage, provided by the RichMessagePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_RichMessage value)?, {required TResult orElse()}) → TResult -
Available on RichMessage, provided by the RichMessagePatterns extension
A variant ofmapthat fallback to returningorElse. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this RichMessage to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited