RichTextType enum
Type of the rich text.
Values
- plain → const RichTextType
-
Plain text (Internal type used for String parsing)
const RichTextType("plain") - collection → const RichTextType
-
Collection of RichText (Internal type used for List parsing)
const RichTextType("collection") - bold → const RichTextType
-
A bold text.
const RichTextType("bold") - italic → const RichTextType
-
An italicized text.
const RichTextType("italic") - underline → const RichTextType
-
An underlined text.
const RichTextType("underline") - strikethrough → const RichTextType
-
A strikethrough text.
const RichTextType("strikethrough") - spoiler → const RichTextType
-
A text covered by a spoiler.
const RichTextType("spoiler") - dateTime → const RichTextType
-
Formatted date and time.
const RichTextType("date_time") - textMention → const RichTextType
-
A mention of a Telegram user by their identifier.
const RichTextType("text_mention") - subscript → const RichTextType
-
A subscript text.
const RichTextType("subscript") - superscript → const RichTextType
-
A superscript text.
const RichTextType("superscript") - marked → const RichTextType
-
A marked text.
const RichTextType("marked") - code → const RichTextType
-
A monowidth text.
const RichTextType("code") - customEmoji → const RichTextType
-
A custom emoji.
const RichTextType("custom_emoji") - mathematicalExpression → const RichTextType
-
A mathematical expression.
const RichTextType("mathematical_expression") - url → const RichTextType
-
A text with a link.
const RichTextType("url") - emailAddress → const RichTextType
-
A text with an email address.
const RichTextType("email_address") - phoneNumber → const RichTextType
-
A text with a phone number.
const RichTextType("phone_number") - bankCardNumber → const RichTextType
-
A text with a bank card number.
const RichTextType("bank_card_number") - mention → const RichTextType
-
A mention by a username.
const RichTextType("mention") - hashtag → const RichTextType
-
A hashtag.
const RichTextType("hashtag") - cashtag → const RichTextType
-
A cashtag.
const RichTextType("cashtag") - botCommand → const RichTextType
-
A bot command.
const RichTextType("bot_command") - anchor → const RichTextType
-
An anchor.
const RichTextType("anchor") - anchorLink → const RichTextType
-
A link to an anchor.
const RichTextType("anchor_link") - reference → const RichTextType
-
A reference.
const RichTextType("reference") - referenceLink → const RichTextType
-
A link to a reference.
const RichTextType("reference_link")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The value of the enum.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts a RichTextType to a string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RichTextType> - A constant List of the values in this enum, in order of their declaration.