UniqueGift class abstract

This object describes a unique gift that was upgraded from a regular gift.

Annotations
  • @freezed

Constructors

UniqueGift({@JsonKey.new(name: 'base_name') required String baseName, @JsonKey.new(name: 'name') required String name, @JsonKey.new(name: 'number') required int number, @JsonKey.new(name: 'model') required UniqueGiftModel model, @JsonKey.new(name: 'symbol') required UniqueGiftSymbol symbol, @JsonKey.new(name: 'backdrop') required UniqueGiftBackdrop backdrop})
Creates a new UniqueGift object.
const
factory
UniqueGift.fromJson(Map<String, dynamic> json)
Creates a new UniqueGift object from a JSON Map.
factory

Properties

backdrop → UniqueGiftBackdrop
Backdrop of the gift
no setterinherited
baseName → String
Human-readable name of the regular gift from which this unique gift was upgraded
no setterinherited
copyWith → $UniqueGiftCopyWith<UniqueGift>
Create a copy of UniqueGift with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
model → UniqueGiftModel
Model of the gift
no setterinherited
name → String
Unique name of the gift. This name can be used in https://t.me/nft/... links and story areas
no setterinherited
number → int
Unique number of the upgraded gift among gifts upgraded from the same regular gift
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol → UniqueGiftSymbol
Symbol of the gift
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this UniqueGift to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited