UserProfileAudios class abstract
This object represents the audios displayed on a user's profile.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
UserProfileAudios({@JsonKey.new(name: 'total_count') required int totalCount, @JsonKey.new(name: 'audios') required List<
Audio> audios}) -
Creates a UserProfileAudios object.
constfactory
-
UserProfileAudios.fromJson(Map<
String, dynamic> json) -
Creates a UserProfileAudios object from a JSON map.
factory
Properties
-
audios
→ List<
Audio> -
Requested profile audios.
no setterinherited
-
copyWith
→ $UserProfileAudiosCopyWith<
UserProfileAudios> -
Create a copy of UserProfileAudios
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
Total number of profile audios for the target user.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_UserProfileAudios value)) → TResult -
Available on UserProfileAudios, provided by the UserProfileAudiosPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_UserProfileAudios value)?) → TResult? -
Available on UserProfileAudios, provided by the UserProfileAudiosPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_UserProfileAudios value)?, {required TResult orElse()}) → TResult -
Available on UserProfileAudios, provided by the UserProfileAudiosPatterns extension
A variant ofmapthat fallback to returningorElse. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this UserProfileAudios to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited