managedBot property
ManagedBotUpdated?
get
managedBot
The managed bot update from the update, if any.
This will be non-null when a managed bot is created or its token changes.
Implementation
ManagedBotUpdated? get managedBot => update.managedBot;