text property
String?
get
text
The text content of the message, if any.
This extracts text from regular messages, channel posts, and callback query messages. The result is cached after the first access for better performance.
Implementation
String? get text {
if (!_textCached) {
_cachedText = msg?.text;
_textCached = true;
}
return _cachedText;
}