answerCallbackQuery method
Use this method to send answers to callback queries sent from inline keyboards. The answer will be displayed to the user as a notification at the top of the chat screen or as an alert. On success, True is returned.
Implementation
Future<bool> answerCallbackQuery(
String callbackQueryId, {
String? text,
bool showAlert = false,
String? url,
int cacheTime = 0,
}) async {
final params = <String, dynamic>{
'callback_query_id': callbackQueryId,
'text': ?text,
'show_alert': showAlert,
'url': ?url,
'cache_time': cacheTime,
};
final payload = Payload(params);
return await _makeRequest<bool>(
APIMethod.answerCallbackQuery.name,
payload,
);
}