UpdateType enum
This object represents type of an incoming update.
Values
- message → const UpdateType
-
Message update
- editedMessage → const UpdateType
-
Edited message update
- channelPost → const UpdateType
-
Channel post update
- editedChannelPost → const UpdateType
-
Edited channel post update
- inlineQuery → const UpdateType
-
Inline query update
- chosenInlineResult → const UpdateType
-
Chosen inline result update
- callbackQuery → const UpdateType
-
Callback query update
- shippingQuery → const UpdateType
-
Shipping query update
- preCheckoutQuery → const UpdateType
-
Pre checkout query update
- poll → const UpdateType
-
Poll update
- pollAnswer → const UpdateType
-
Poll answer update
- myChatMember → const UpdateType
-
My chat member update
- chatMember → const UpdateType
-
Chat member update
- chatJoinRequest → const UpdateType
-
Chat join request update
- messageReaction → const UpdateType
-
A reaction to a message was changed by a user.
- messageReactionCount → const UpdateType
-
Update when reactions to a message with anonymous reactions were changed.
- chatBoost → const UpdateType
-
Update when a chat is boosted.
- removedChatBoost → const UpdateType
-
Update when a chat boost is removed.
- businessConnection → const UpdateType
-
Update when a business connection is established.
- businessMessage → const UpdateType
-
When a message from a connected business account is recieved
- editedBusinessMessage → const UpdateType
-
New version of a message from a connected business account
- deletedBusinessMessages → const UpdateType
-
Messages were deleted from a connected business account
- purchasedPaidMedia → const UpdateType
-
Updates about purchased paid media
- managedBot → const UpdateType
-
Update when a new managed bot is created or its token changes.
- guestMessage → const UpdateType
-
New guest message.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isCallbackQuery → bool
-
Check if the update is a callback query update
no setter
- isChannelPost → bool
-
Check if the update is a channel post update
no setter
- isChatJoinRequest → bool
-
Check if the update is a chat join request update
no setter
- isChatMember → bool
-
Check if the update is a chat member update
no setter
- isChosenInlineResult → bool
-
Check if the update is a chosen inline result update
no setter
- isEditedChannelPost → bool
-
Check if the update is an edited channel post update
no setter
- isEditedMessage → bool
-
Check if the update is an edited message update
no setter
- isGuestMessage → bool
-
Check if the update is a guest message update
no setter
- isInlineQuery → bool
-
Check if the update is an inline query update
no setter
- isManagedBot → bool
-
Check if the update is a managed bot update
no setter
- isMessage → bool
-
Check if the update is a message update
no setter
- isMessageReaction → bool
-
Check if the update is a message reaction update
no setter
- isMessageReactionCount → bool
-
Check if the update is a message reaction count update
no setter
- isMyChatMember → bool
-
Check if the update is a my chat member update
no setter
- isPoll → bool
-
Check if the update is a poll update
no setter
- isPollAnswer → bool
-
Check if the update is a poll answer update
no setter
- isPreCheckoutQuery → bool
-
Check if the update is a pre checkout query update
no setter
- isShippingQuery → bool
-
Check if the update is a shipping query update
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts the UpdateType to its corresponding JSON value.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
messages(
) → List< UpdateType> - List of update types that related to a Message event.
Constants
-
values
→ const List<
UpdateType> - A constant List of the values in this enum, in order of their declaration.